#astra-sites-5-start-notice .notice-container {
	padding-top: 10px;
	padding-bottom: 10px;
	display: flex;
	justify-content: left;
	align-items: center;
}

#astra-sites-5-start-notice .notice-content {
	margin-left: 15px;
}

#astra-sites-5-start-notice .notice-image img {
	width: 90px;
}

#astra-sites-5-start-notice .astra-review-notice-container {
	display: flex;
	align-items: center;
	padding-top: 10px;
}

#astra-sites-5-start-notice .astra-review-notice-container .dashicons {
	font-size: 1.4em;
	padding-left: 10px;
}

#astra-sites-5-start-notice .astra-review-notice-container a {
	padding-left: 5px;
	text-decoration: none;
}
