export const SET_WEBSITE_TYPE_AI_STEP = 'SET_WEBSITE_TYPE_AI_STEP';
export const SET_WEBSITE_LANGUAGE_AI_STEP = 'SET_WEBSITE_LANGUAGE_AI_STEP';
export const SET_WEBSITE_TYPE_LIST_AI_STEP = 'SET_WEBSITE_TYPE_LIST_AI_STEP';
export const SET_WEBSITE_LANGUAGE_LIST_AI_STEP =
	'SET_WEBSITE_LANGUAGE_LIST_AI_STEP';

export const SET_LIMIT_EXCEED_MODAL = 'SET_LIMIT_EXCEED_MODAL';
export const SET_API_ERROR_MODAL = 'SET_API_ERROR_MODAL';
export const SET_CONTINUE_PROGRESS_MODAL = 'SET_CONTINUE_PROGRESS_MODAL';
export const SET_PLAN_INFORMATION_MODAL = 'SET_PLAN_INFORMATION_MODAL';

export const SET_WEBSITE_NAME_AI_STEP = 'SET_WEBSITE_NAME_AI_STEP';
export const SET_WEBSITE_DETAILS_AI_STEP = 'SET_WEBSITE_DETAILS_AI_STEP';
export const SET_WEBSITE_KEYWORDS_AI_STEP = 'SET_WEBSITE_KEYWORDS_AI_STEP';
export const SET_WEBSITE_IMAGES_AI_STEP = 'SET_WEBSITE_IMAGES_AI_STEP';
export const RESET_KEYWORDS_IMAGES_AI_STEP = 'RESET_KEYWORDS_IMAGES_AI_STEP';
export const SET_WEBSITE_ONBOARDING_AI_DETAILS =
	'SET_WEBSITE_ONBOARDING_AI_DETAILS';
export const SET_WEBSITE_CONTACT_AI_STEP = 'SET_WEBSITE_CONTACT_AI_STEP';
export const SET_WEBSITE_TEMPLATES_AI_STEP = 'SET_WEBSITE_TEMPLATES_AI_STEP';
export const SET_WEBSITE_TEMPLATE_RESULTS_AI_STEP =
	'SET_WEBSITE_TEMPLATE_RESULTS_AI_STEP';
export const SET_WEBSITE_SELECTED_TEMPLATE_AI_STEP =
	'SET_WEBSITE_SELECTED_TEMPLATE_AI_STEP';
export const SET_SELECTED_TEMPLATE_IS_PREMIUM =
	'SET_SELECTED_TEMPLATE_IS_PREMIUM';
export const SET_WEBSITE_DATA_AI_STEP = 'SET_WEBSITE_DATA_AI_STEP';
export const RESET_ONBOARDING_AI_STEPS = 'RESET_ONBOARDING_AI_STEPS';
export const SET_ONBOARDING_AI_DETAILS = 'SET_ONBOARDING_AI_DETAILS';
export const SET_CREDITS_DETAILS = 'SET_CREDITS_DETAILS';
export const TOGGLE_UPDATE_ONBOARDING_IMAGES =
	'TOGGLE_UPDATE_ONBOARDING_IMAGES';
export const STORE_SITE_FEATURES = 'STORE_SITE_FEATURES';
export const SET_SITE_FEATURES_DATA = 'SET_SITE_FEATURES_DATA';
export const SET_SITE_FEATURES = 'SET_SITE_FEATURES';
export const SET_WEBSITE_TEMPLATE_KEYWORDS = 'SET_WEBSITE_TEMPLATE_KEYWORDS';
export const SET_DYNAMIC_CONTENT = 'SET_DYNAMIC_CONTENT';
export const LOADING_NEXT_STEP = 'LOADING_NEXT_STEP';

// Logo, Typography and Colors
export const SET_WEBSITE_LOGO = 'SET_WEBSITE_LOGO';
export const SET_SITE_TITLE_VISIBLE = 'SET_SITE_TITLE_VISIBLE';
export const SET_WEBSITE_COLOR_PALETTE = 'SET_WEBSITE_COLOR_PALETTE';
export const SET_WEBSITE_TYPOGRAPHY = 'SET_WEBSITE_TYPOGRAPHY';
export const SET_DEFAULT_COLOR_PALETTE = 'SET_DEFAULT_COLOR_PALETTE';

// Import & Build AI Site
export const UPDATE_IMPORT_AI_SITE_DATA = 'UPDATE_IMPORT_AI_SITE_DATA';
export const SET_FULL_ONBOARDING_STATE = 'SET_FULL_ONBOARDING_STATE';
