.bsf-quick-link-items-wrap,
.bsf-quick-link {
    position: fixed;
    z-index: 10;
    transition: all 0.2s ease-in-out;
    opacity: 1;
}

.bsf-quick-link-items-wrap{
    right: 2.2rem;
    bottom: 8em;
}

.bsf-quick-link{
    right: 25px;
    bottom: 40px;
}

.bsf-quick-link-wrap a {
    text-decoration: none;
}

.bsf-quick-link-wrap a:focus {
    text-decoration: none;
    box-shadow: unset;
    outline: unset;
}

.bsf-quick-link-item {
    display: flex;
    justify-content: flex-end;
    margin-bottom: 15px;
}

.menu-item-logo {
    margin-left: 14px;
    font-size: 18px;
    color: white;
    background: #005e9b;
    padding: 12px;
    border-radius: 50%;
    height: 18px;
    width: 18px;
}

.bsf-quick-link-label {
    color: #fff;
    background: #5C5C5C;
    white-space: nowrap;
    padding: 5px 10px;
    border-radius: 3px;
    -moz-border-radius: 3px;
    -webkit-border-radius: 3px;
    height: 14px;
    margin-top: 9px;
    font-size: 12px;
    border: 1px solid #959595;
    line-height: 1;
    position: absolute;
    right: 55px;
}

.menu-item-logo:hover{
    filter:brightness(150%);
}

.dashicons-star-filled.menu-item-logo:hover{
    filter:brightness(120%);
}

.bsf-quick-link-items-wrap.hide-wrapper .bsf-quick-link-item  {
	visibility: hidden;
}

.bsf-quick-link-item {
	-webkit-transition: -webkit-transform .2s;
    transition: -webkit-transform .2s;
    transition: transform .2s;
    transition: transform .2s,-webkit-transform .2s;
}

.bsf-quick-link-items-wrap.show-popup .bsf-quick-link-item {
    -webkit-transform: scale(1);
    -ms-transform: scale(1);
    transform: scale(1);
}

.bsf-quick-link-items-wrap .bsf-quick-link-item {
    -webkit-transform: scale(0);
    -ms-transform: scale(0);
    transform: scale(0);
}

.quick-link-button-wrap {
	background: #ffffff;
	border-radius: 30px;
	color: #000;
	padding: 6px 18px;
	border: 2px solid #4400C1;
	font-weight: 500;
	box-shadow: 0px 8px 18px 0px rgb(0 0 0 / 25%);
	display: flex;
	align-items: center;
	height:30px;
}

.quick-link-button-wrap img {
	height: auto;
	width: 22px;
	margin-right: 10px;
}
