:root{--ast-spectra-ai-primary: #0073aa;--ast-spectra-ai-primary-hover: #007cba;--ast-spectra-ai-primary-text: #fff;--ast-spectra-ai-heading-text: #030712;--ast-spectra-ai-text: #374151;--ast-spectra-ai-icon-active: #111827;--ast-spectra-ai-icon-inactive: #374151}.spectra-ai-block-layout{font-family:Inter,sans-serif}.spectra-ai-block-layout.block-wrapper{width:100%;max-width:544px !important;padding:32px;border-radius:5px;display:flex;flex-direction:column;gap:32px}.spectra-ai-block-layout.block-wrapper:hover{box-shadow:none}.spectra-ai-block-layout .block-heading-wrapper{display:flex;flex-direction:column;align-items:center;justify-content:flex-start;gap:12px}.spectra-ai-block-layout .block-title{font-size:24px;font-weight:600;line-height:33.6px;text-align:center;margin:0 !important;padding:0 !important;color:var(--ast-spectra-ai-heading-text)}.spectra-ai-block-layout .block-description{font-size:16px;font-weight:400;line-height:24px;text-align:center;margin:0 !important;padding:0 !important;color:var(--ast-spectra-ai-text)}.spectra-ai-block-layout .block-button{font-size:16px;font-weight:500;line-height:24px;padding:8px 20px;border-radius:4px;display:flex;align-items:center;justify-content:center;gap:8px;transition:color .15s ease-in-out}.spectra-ai-block-layout .block-button.prefix-icon{padding-left:12px}.spectra-ai-block-layout .button-icon{width:24px;height:24px}.spectra-ai-block-layout .button-primary{background-color:var(--ast-spectra-ai-primary);border-color:var(--ast-spectra-ai-primary);color:var(--ast-spectra-ai-primary-text)}.spectra-ai-block-layout .button-primary:hover{background-color:var(--ast-spectra-ai-primary-hover);border:1px solid var(--ast-spectra-ai-primary-hover);color:var(--ast-spectra-ai-primary-text)}.spectra-ai-block-layout .button-secondary{background-color:#fff;color:var(--ast-spectra-ai-primary);border:1px solid var(--ast-spectra-ai-primary)}.spectra-ai-block-layout .button-secondary:hover{background-color:#fff;color:var(--ast-spectra-ai-primary-hover);border:1px solid var(--ast-spectra-ai-primary-hover)}.spectra-ai-block-layout .block-buttons{display:flex;align-items:center;justify-content:center;gap:16px}.spectra-ai-block-layout .close-button{position:absolute;top:16px;right:16px;width:24px;height:24px;cursor:pointer;border:none;outline:none;background:none;color:var(--ast-spectra-ai-icon-inactive);transition:color .15s ease-in-out}.spectra-ai-block-layout .close-button:hover{color:var(--ast-spectra-ai-icon-active)}.spectra-ai-block-layout .close-button .close-button-icon{width:24px;height:24px}.spectra-ai-block-layout+.block-list-appender .block-editor-default-block-appender{display:none !important}
