.survey-loading-container {
	padding: 5%;
	background: #f7f7f9;
	padding: 5%;
	overflow-y: auto;
	flex: 1;
	height: 100%;
	border-radius: var( --st-border-radius-2 );

	.loading-container {
		background: var( --st-background-primary );
		box-shadow: 0px 4px 6px -2px rgba( 0, 0, 0, 0.05 ), 0px 10px 15px -3px rgba( 0, 0, 0, 0.1 );
		border-radius: var( --st-border-radius-4 );
		width: 600px;
		padding: 35px;
		margin: 0 auto;
		text-align: left;
	}
}
