.page-builder-screen-wrap {
	.page-builder-wrap {
		margin: 0 auto;
		max-width: 800px;
		padding: 0 20px;
		display: grid;
		column-gap: 16px;
		justify-content: center;
		grid-auto-columns: minmax( 0, 1fr );
		grid-auto-flow: column;
		align-items: center;
	}
}

#wpbody {
	padding-top: 0 !important;
}
