.st-sync-library {
	cursor: pointer;
	margin: 0 20px;

	.stc-tooltip-content {
		right: 0;
	}

	&.loading {
		svg {
			animation: rotate 2s infinite linear;
		}
	}

	@keyframes rotate {
		from {
			transform: rotate( 0deg );
		}
		to {
			transform: rotate( 360deg );
		}
	}
}
