@import "../../../variables.scss";

.st-no-favorites {
	background: var( --st-background-secondary );
	border-bottom: 1px solid var( --st-border-color );
	box-sizing: border-box;
	padding: 45px 30px 40px 0;
	text-align: left;
}
