.ist-color-palette{background:var(--st-background-primary);border:1px solid var(--st-border-color);box-sizing:border-box;border-radius:var(--st-border-radius-4);display:flex;align-items:center;padding:8px;cursor:pointer;transition:all .2s ease-in-out;justify-content:space-evenly}.ist-color-palette:hover,.ist-color-palette:focus,.ist-color-palette.ist-color-palette-active{border-color:var(--st-color-accent)}.ist-color-palette:hover .ist-color-icon,.ist-color-palette:focus .ist-color-icon{border-color:var(--st-color-accent)}.ist-color-palette-active .ist-color-icon{background:var(--st-color-accent);border-color:var(--st-color-accent)}.ist-palette-color{width:20px;height:20px;border-radius:50%;border:1px solid #eee}.ist-palette-color:first-child{margin-left:0}.ist-colors-list{display:flex;flex:1;justify-content:space-between}.ist-colors-title{display:flex;align-items:center;font-size:var(--st-font-size-xs);font-weight:var(--st-font-weight-bold);color:var(--st-color-heading);line-height:var(--st-font-line-height-s)}.ist-color-icon{background:var(--st-background-primary);border:1px solid var(--st-border-color);box-sizing:border-box;width:18px;height:18px;border-radius:50%;transition:all .2s ease-in-out;padding:4px}.ist-color-palette-active{border:1px solid rgba(0,0,0,0)}.st-default-style-pallete{margin-top:25px;margin-bottom:15px}.st-default-style-pallete .ist-color-palette{display:grid;grid-template-columns:53% 47%}.st-default-style-pallete .ist-colors-list{padding-left:8px}.st-others-style-pallete{display:grid;grid-template-columns:repeat(2, 1fr);grid-gap:15px}
.ist-font{border-radius:var(--st-border-radius-4);margin-bottom:0;cursor:pointer;background:var(--st-background-primary);border:1px solid var(--st-border-color);transition:all 200ms ease-in-out}.ist-font:hover,.ist-font:focus{border:1px solid var(--st-color-accent);outline:none}.ist-font:hover svg path,.ist-font:focus svg path{fill:var(--st-color-heading)}.ist-font.active{border:1px solid var(--st-color-accent)}.ist-sep{border:1px solid var(--st-border-color)}.ist-font-selector{margin:0;padding:0}.ist-default-fonts .ist-font,.ist-other-fonts .ist-font{padding:12px;line-height:1;text-align:left}.ist-default-fonts .font-separator,.ist-other-fonts .font-separator{margin:0 5px}.ist-other-fonts{display:grid;grid-template-columns:repeat(4, 1fr);grid-gap:10px;font-size:var(--st-font-size-m)}.ist-other-fonts .ist-font{text-align:left;display:flex;justify-content:center;align-content:center;align-items:baseline;color:var(--st-color-heading)}.ist-other-fonts svg{vertical-align:middle;fill:var(--st-color-heading);margin:13px;width:auto}.ist-other-fonts .active svg path{border:1px solid var(--st-color-accent)}.ist-other-fonts .stc-tooltip:nth-child(odd) .stc-tooltip-content{left:0}.ist-other-fonts .stc-tooltip:nth-child(even) .stc-tooltip-content{right:0}.ist-other-fonts .stc-tooltip-content{top:3.5rem}.customize-site-typography .ist-default-fonts-heading{margin:0px 0px 17px 0}.ist-default-fonts{margin-top:25px;margin-bottom:15px}.ist-default-fonts .heading-font-preview{font-size:var(--st-font-size-m);color:var(--st-color-heading)}.ist-default-fonts .body-font-preview{color:var(--st-color-body);font-size:var(--st-font-size-m)}.ist-other-fonts .heading-font-preview{font-size:var(--st-font-size-xl)}.ist-other-fonts .body-font-preview{font-size:var(--st-font-size-xl)}
.step-site-list,.starter-templates-ai-steps{--stc-toggle-dropdown-popup-item-cursor: pointer}.st-other-filters{position:relative;display:flex;align-items:center;justify-content:space-between;border-bottom:1px solid #d1d5db;padding-bottom:8px}.st-category-filter{flex:1}.stc-category-list-item{border-bottom:2px solid rgba(0,0,0,0);padding:0 !important;margin:0 28px 0 0;margin-bottom:-26px;margin-top:-20px;font-size:14px;color:var(--st-color-placeholder);font-weight:var(--stc-font-weight-bold)}.stc-category-list-item.active{border-color:var(--stc-color-heading)}.st-type-and-order-filters{--stc-toggle-dropdown-popup-item-padding: 5px 17px;--stc-toggle-dropdown-popup-padding: 8px 0px;display:flex}.st-site-type-filter{margin-right:30px}.st-sites-grid{min-height:100vh;margin-top:65px;position:relative}.st-sites-grid .stc-grid-item-title{font-size:var(--st-font-size-xs);line-height:var(--st-line-height-xs);color:var(--st-color-heading);padding:0;margin:0}.stc-site-order-filter,.stc-site-type-filter{width:110px}.stc-site-order-filter .stc-toggle-dropdown-popup,.stc-site-type-filter .stc-toggle-dropdown-popup{top:120%}.stc-site-order-filter .stc-toggle-dropdown-popup-item,.stc-site-type-filter .stc-toggle-dropdown-popup-item{padding:9px 17px;font-size:var(--stc-font-size-xs);color:var(--stc-color-body)}.stc-site-order-filter .stc-toggle-dropdown-popup-item:first-child:hover,.stc-site-order-filter .stc-toggle-dropdown-popup-item.active:first-child,.stc-site-order-filter .stc-toggle-dropdown-popup-item:last-child:hover,.stc-site-order-filter .stc-toggle-dropdown-popup-item.active:last-child,.stc-site-type-filter .stc-toggle-dropdown-popup-item:first-child:hover,.stc-site-type-filter .stc-toggle-dropdown-popup-item.active:first-child,.stc-site-type-filter .stc-toggle-dropdown-popup-item:last-child:hover,.stc-site-type-filter .stc-toggle-dropdown-popup-item.active:last-child{border-radius:0 0 var(--stc-border-radius-4) var(--stc-border-radius-4)}.stc-site-type-filter{margin-right:15px}.st-related-site-message,.st-suggested-site-message,.st-sites-found-message{text-align:left;font-size:var(--st-font-size-xs);color:var(--st-color-heading)}.step-site-list .step-actions p{font-weight:500;font-size:22px;color:#3b3f5c}.step-site-list #ist-bashcanvas{display:none}.st-sites-found-message{position:absolute;top:-40px}.site-loading .site-list-screen-wrap{opacity:0}.site-loaded .site-list-loading-skeleton{display:none;transition:opacity 1s ease-out;opacity:0}.site-loaded .site-list-screen-wrap{animation:300ms ease 0s normal forwards 1 fadein}@keyframes fadein{0%{opacity:.7}100%{opacity:1}}.cta-strip-right{display:flex;justify-content:center;align-items:center;align-content:center;grid-gap:40px}.stc-extra-text.stc-logo{align-items:flex-start}.stc-extra-text::after{background:linear-gradient(90deg, #b809a7 0%, #e90b76 46.88%, #fc8536 100%);-webkit-background-clip:text;background-clip:text;color:rgba(0,0,0,0);font-size:12px;font-weight:500;line-height:12px;text-align:center;content:attr(data-extratext);text-align:left;margin-left:8px}@media screen and (min-width: 768px){.st-other-filters{padding-left:22px}}
.st-search-filter{--stc-suggestion-list-max-width: 740px;--stc-suggestion-list-padding: 10px 20px;--stc-suggestion-list-margin: 0 auto;--stc-suggestion-list-position: absolute;--stc-suggestion-list-border-radius: 0 0 4px 4px}.st-search-box-wrap{min-height:63px}.st-search-filter{margin-top:20px;margin-bottom:42px;position:relative;display:inline-block}.st-search-filter .stc-suggestion-list{border-top:none}.stc-search .stc-search-input{width:670px !important;padding-left:40px !important}@media only screen and (max-width: 768px){.stc-search .stc-search-input{width:320px !important}}.st-search-box-fixed .st-search-box{--stc-search-input-box-shadow: none;--stc-search-input-height: 52px;--stc-search-input-border: 1px solid var( --st-border-color );--stc-search-input--focus-border: 1px solid var( --st-border-color );position:fixed;top:14px;left:112px;max-width:742px;margin:0}.st-search-box-fixed .st-search-box .stc-search .stc-search-input{width:670px !important;padding-left:40px !important}@media only screen and (max-width: 768px){.st-search-box-fixed .st-search-box .stc-search .stc-search-input{width:320px !important}}@media only screen and (min-width: 768px)and (max-width: 1024px){.st-search-box-fixed .st-search-box .stc-search .stc-search-input{width:400px !important}}.st-templates-content{margin-top:10px;margin-bottom:10px;--stc-sites-no-results-padding: 45px 30px 40px 0}.site-list-content{margin-top:20px}
body{--st-color-accent: #2563eb;--st-color-accent-hover: #1d4ed8;--st-color-heading: #1f2937;--st-color-body: #4b5563;--st-color-light-gray: #e5e7eb;--st-color-placeholder: #6b7280;--st-color-white: #ffffff;--st-color-favorite: #e91e63;--st-background-secondary: #f7f7f9;--st-background-primary: #ffffff;--st-background-light: #f9fafb;--st-tooltip-background: #020617;--st-font-size-xxl: 30px;--st-font-size-xl: 24px;--st-font-size-l: 20px;--st-font-size-m: 18px;--st-font-size-s: 16px;--st-font-size-xs: 14px;--st-font-weight-extra-bold: 600;--st-font-weight-bold: 500;--st-font-weight-normal: 400;--st-font-line-height-xl: 36px;--st-font-line-height-l: 32px;--st-font-line-height-m: 28px;--st-font-line-height-s: 24px;--st-font-line-height-xs: 20px;--st-border-color: #d1d5db;--st-border-radius-6: 6px;--st-border-radius-4: 4px;--st-border-radius-3: 3px;--st-border-radius-2: 2px;--st-border-radius-1: 1px}.zw-xxs-medium{font-size:.625rem;font-weight:500;line-height:.75rem}.zw-xs-normal{font-size:.75rem;font-weight:400;line-height:1rem}.zw-xs-medium{font-size:.75rem;font-weight:500;line-height:1rem}.zw-xs-semibold{font-size:.75rem;font-weight:600;line-height:1rem}.zw-sm-normal{font-size:.875rem;font-weight:400;line-height:1.25rem}.zw-sm-medium{font-size:.875rem;font-weight:500;line-height:1.25rem}.zw-sm-semibold{font-size:.875rem;font-weight:600;line-height:1.25rem}.zw-base-normal{font-size:1rem;font-weight:400;line-height:1.5rem}.zw-base-medium{font-size:1rem;font-weight:500;line-height:1.5rem}.zw-base-semibold{font-size:1rem;font-weight:600;line-height:1.5rem}.zw-base-bold{font-size:1rem;font-weight:700;line-height:1.5rem}.zw-h1{font-size:1.875rem;font-weight:700;line-height:2.25rem;color:var(--app-heading)}.zw-h2{font-size:1.5rem;font-weight:600;line-height:2rem;color:var(--app-heading)}.zw-h3{font-size:1.25rem;font-weight:600;line-height:1.25rem;color:var(--app-heading)}.zw-h4{font-size:1.125rem;font-weight:700;line-height:1.75rem;color:var(--app-heading)}.zw-h5{font-size:1rem;font-weight:600;line-height:1rem;color:var(--app-heading)}.zw-h6{font-size:.875rem;font-weight:600;line-height:.875rem;color:var(--app-heading)}.st-no-favorites{background:var(--st-background-secondary);border-bottom:1px solid var(--st-border-color);box-sizing:border-box;padding:45px 30px 40px 0;text-align:left}
.step-header{--stc-toggle-dropdown-border-color: transparent;--stc-toggle-dropdown-popup-item-margin: 0 0 10px 0;--stc-toggle-dropdown-padding: 10px 10px 10px 10px;--stc-toggle-dropdown-selected-padding: 27px 20px 27px 20px;--stc-toggle-dropdown-popup-top: 100%;--stc-toggle-dropdown-popup-left: 10px;--stc-toggle-dropdown-icon-height: 7px;position:relative}.step-header .row{padding:0;position:relative;pointer-events:none;z-index:1}.step-header .row .st-header-left,.step-header .row .st-header-right{pointer-events:auto}.step-header .row #st-whats-new{pointer-events:auto;margin:0 20px 5px 0}.step-header .row #st-whats-new .whats-new-rss-trigger-button{padding:0}.step-header .row #st-whats-new .whats-new-rss-trigger-button svg path{fill:var(--st-color-placeholder)}.step-header .st-exit-to-dashboard{padding:26px 26px}.step-header .st-exit-to-dashboard svg{margin:0}.step-header .st-page-builder-filter{border-left:1px solid var(--st-border-color);border-right:1px solid var(--st-border-color)}.step-header .st-page-builder-filter .st-page-builder-toggle .stc-toggle-dropdown-selected{width:-moz-fit-content;width:fit-content;min-width:228px}.step-header .st-page-builder-filter .st-page-builder-toggle .stc-toggle-dropdown-selected .stc-logo-image{border-radius:unset}.step-header .st-page-builder-filter .st-page-builder-toggle .stc-toggle-dropdown-popup{z-index:999999;--stc-toggle-dropdown-popup-top: 103%;border-radius:0 0 var(--stc-border-radius-4) var(--stc-border-radius-4);width:100%;min-width:228px;left:0}.step-header .st-page-builder-filter .st-page-builder-toggle .stc-toggle-dropdown-popup .stc-logo-image{border-radius:unset}.step-header .st-page-builder-filter+.col.exit-link{border-left-width:0}@media(min-width: 768px)and (max-width: 820px){.step-header .st-page-builder-filter .st-page-builder-toggle .stc-toggle-dropdown-selected{min-width:0}.step-header .st-page-builder-filter .st-page-builder-toggle .stc-toggle-dropdown-selected .stc-logo-text{display:none}.step-header .st-page-builder-filter .st-page-builder-toggle .stc-toggle-dropdown-popup{min-width:0}.step-header .st-page-builder-filter .st-page-builder-toggle .stc-toggle-dropdown-popup .stc-logo-text{display:none}}
.ist-logo{--stc-logo-height: 40px;--stc-logo-width: 40px}

.st-my-favorite{cursor:pointer}.st-my-favorite svg{width:16px;height:16px;fill:var(--st-color-placeholder)}.st-my-favorite.active svg,.st-my-favorite :hover svg{fill:var(--st-color-favorite)}.st-my-favorite .stc-tooltip-content{right:0}
.st-sync-library{cursor:pointer;margin:0 20px}.st-sync-library .stc-tooltip-content{right:0}.st-sync-library.loading svg{animation:rotate 2s infinite linear}@keyframes rotate{from{transform:rotate(0deg)}to{transform:rotate(360deg)}}
.change-template-wrap{padding:4% 8%;background:var(--st-background-secondary);display:flex;align-items:center;align-content:center;justify-content:space-between;border-bottom:1px solid var(--st-border-color)}.change-template-wrap .template-name h5{color:var(--st-color-body);margin-bottom:5px}.change-template-wrap .stc-grid-item-badge{position:unset}.change-template-wrap .label{color:var(--st-color-placeholder)}.change-template-wrap .change-btn-wrap{cursor:pointer}.change-template-wrap .change-btn{background:rgba(0,0,0,0);border:1px solid #626262;border-radius:var(--st-border-radius-3);padding:6px;font-weight:var(--st-font-weight-normal);font-size:var(--st-font-size-xs);line-height:var(--st-font-line-height-l);display:flex;align-content:center;justify-content:center;align-items:center}.change-template-wrap .change-btn:hover{border-color:var(--st-color-heading)}.change-template-wrap .change-btn:hover svg path{fill:var(--st-color-heading)}
.customizer-ecommerce-selection{display:flex;flex-direction:column;gap:15px;margin-top:10px}.customizer-ecommerce-selection label.ist-customizer-heading{position:relative;border-color:var(--st-color-accent);background:var(--st-background-primary);border:1px solid var(--st-border-color);box-sizing:border-box;border-radius:var(--st-border-radius-4);display:flex;align-items:center;padding:15px;cursor:pointer;transition:all .2s ease-in-out;justify-content:space-between}.customizer-ecommerce-selection label.ist-customizer-heading .ist-image-section{display:flex;gap:5px;align-items:center}.customizer-ecommerce-selection label.ist-customizer-heading .ist-image-section span{font-weight:600}.customizer-ecommerce-selection .stc-tooltip{position:unset}.customizer-ecommerce-selection .stc-tooltip path{fill:#6b7280 !important}.customizer-ecommerce-selection .stc-tooltip .stc-tooltip-content{top:85%;line-height:inherit;min-width:200px}@media(max-width: 992px){.customizer-ecommerce-selection{font-size:12px}.customizer-ecommerce-selection img{width:16px}.customizer-ecommerce-selection svg{width:12px}}@media(max-width: 768px){.customizer-ecommerce-selection{font-size:10px}.customizer-ecommerce-selection input[type=radio]{width:1rem;height:1rem}.customizer-ecommerce-selection input[type=radio]:checked:before{margin:.1rem}}
.ist-error-message-wrap h2.ist-error-message-title{margin-bottom:30px}.ist-import-error p{display:flex;align-items:center;text-align:left;justify-content:flex-start;margin:0}.ist-import-error .ist-import-error-box{width:100%;border:1px solid var(--st-border-color);box-sizing:border-box;border-radius:var(--st-border-radius-4);justify-content:center;margin:17px auto 25px;padding:20px;background:var(--st-background-light)}.ist-import-error .ist-import-error-solution{margin-top:5px;flex-direction:column;align-items:start;gap:8px;display:block}.ist-import-error .ist-import-error-secondary-wrap{overflow:auto;max-height:200px;margin-top:10px}.ist-import-error .ist-import-error-text-heading{margin-top:30px;margin-bottom:10px}.ist-import-error .ist-import-error-text{padding:10px;border-radius:var(--st-border-radius-4);background-color:var(--st-background-error-text, #efefef)}.ist-import-error pre{margin:0;text-align:left;max-height:100px;overflow:auto}.ist-import-error .ist-import-error-box-heading{margin-bottom:10px}.ist-import-error .ist-import-error-solution-heading{margin:20px 0 0}.ist-import-error .ist-import-error-box-heading,.ist-import-error .ist-import-error-text-heading,.ist-import-error .ist-import-error-solution-heading{text-align:left;font-size:var(--st-font-size-xs, 14px);font-weight:var(--st-font-weight-bold, 500);line-height:var(--st-font-line-height-xs, 20px);color:var(--st-color-heading)}
.website-import-subtitle{margin-bottom:35px;color:#3b3f5c;font-weight:500;font-size:19px;line-height:22px}.website-import-subtitle svg{vertical-align:bottom;margin-left:10px}.step-import-site.st-step h1{text-align:left}.step-import-site.st-step button{width:100%;margin-top:25px}.ist-import-progress-info-text{display:flex;align-items:center;align-content:center;grid-gap:10px}.ist-import-progress,.ist-import-error{margin-top:25px}.ist-import-progress .ist-import-progress-bar-wrap,.ist-import-error .ist-import-progress-bar-wrap{position:relative}.ist-import-progress .import-progress-gap span,.ist-import-error .import-progress-gap span{background:var(--st-background-primary);height:6px;position:absolute;width:10px;top:-1px}.ist-import-progress .import-progress-gap span:nth-child(1),.ist-import-error .import-progress-gap span:nth-child(1){left:calc(25% - 10px)}.ist-import-progress .import-progress-gap span:nth-child(2),.ist-import-error .import-progress-gap span:nth-child(2){left:calc(50% - 10px)}.ist-import-progress .import-progress-gap span:nth-child(3),.ist-import-error .import-progress-gap span:nth-child(3){left:calc(75% - 10px)}.ist-import-progress .ist-import-progress-bar-bg,.ist-import-error .ist-import-progress-bar-bg{height:4px;background:var(--st-color-light-gray);width:100%;position:relative}.ist-import-progress .ist-import-progress-bar-bg .ist-import-progress-bar,.ist-import-error .ist-import-progress-bar-bg .ist-import-progress-bar{position:absolute;left:0;top:0;background:var(--st-color-accent);transition:all 1s;width:0%;height:100%}.ist-import-progress .ist-import-progress-bar-bg .ist-import-progress-bar.import-1,.ist-import-error .ist-import-progress-bar-bg .ist-import-progress-bar.import-1{width:25%}.ist-import-progress .ist-import-progress-bar-bg .ist-import-progress-bar.import-2,.ist-import-error .ist-import-progress-bar-bg .ist-import-progress-bar.import-2{width:50%}.ist-import-progress .ist-import-progress-bar-bg .ist-import-progress-bar.import-3,.ist-import-error .ist-import-progress-bar-bg .ist-import-progress-bar.import-3{width:75%}.ist-import-progress .ist-import-progress-bar-bg .ist-import-progress-bar.import-4,.ist-import-error .ist-import-progress-bar-bg .ist-import-progress-bar.import-4{width:100%}.ist-import-progress .ist-import-progress-bar-bg .ist-import-progress-bar.import-done,.ist-import-error .ist-import-progress-bar-bg .ist-import-progress-bar.import-done{background:#38c172}.ist-import-progress .ist-import-progress-info,.ist-import-error .ist-import-progress-info{display:flex;justify-content:space-between;align-items:center;margin-top:15px;margin-bottom:15px}.ist-import-error .ist-import-error-box{overflow-y:scroll}.ist-import-error .ist-import-progress-bar-bg{width:100%;margin-bottom:15px}.ist-import-error .ist-import-progress-bar-bg .ist-import-progress-bar{background:var(--st-border-color)}.import-done-congrats{display:flex;align-items:center}.import-done-congrats span{margin-left:17px}.import-done-section{margin-top:60px}.import-done-section .tweet-import-success .tweet-text{background:#fff;border:1px solid rgba(34,101,235,.1);border-radius:4px;padding:14px 21px 14px 21px}.import-done-section .tweet-import-success .twitter-btn-wrap{display:flex;align-items:center;gap:7px;right:30px;position:absolute;margin-top:8px;text-decoration:none}.import-done-section .import-done-text{margin-top:60px}.import-done-section .import-done-text .import-done-counter{text-align:left}.import-done-section .import-done-text .import-done-button{margin-top:25px;margin-bottom:15px}.import-done-section .import-done-text .view-dashboard-link{text-decoration:none}.ist-import-done-inner,.import-done-counter,.import-done-section{display:none}.import-done .import-status-string,.import-done .ist-import-text-inner{display:none}.import-done .import-done-counter,.import-done .ist-import-done-inner,.import-done .import-done-section{display:block}
.survey-container{background:var(--st-background-primary);box-shadow:0px 4px 6px -2px rgba(0,0,0,.05),0px 10px 15px -3px rgba(0,0,0,.1);border-radius:var(--st-border-radius-4);width:600px;padding:35px;margin:0 auto 40px;text-align:left}.survey-container input[type=checkbox]:checked:before{content:url("data:image/svg+xml;utf8,<svg%20xmlns%3D%27http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%27%20viewBox%3D%270%200%2020%2020%27><path%20d%3D%27M14.83%204.89l1.34.94-5.81%208.38H9.02L5.78%209.67l1.34-1.25%202.57%202.4z%27%20fill%3D%27%232563EB%27%2F><%2Fsvg>")}.survey-container .required-plugins-form h5,.survey-container .install-plugins-form h5{margin-bottom:22px}.survey-container .required-plugins-form p,.survey-container .install-plugins-form p{margin-bottom:26px}.survey-container .required-plugins-form .third-party-required-plugins-list,.survey-container .required-plugins-form .manual-required-plugins-list,.survey-container .install-plugins-form .third-party-required-plugins-list,.survey-container .install-plugins-form .manual-required-plugins-list{list-style:auto;margin:10px 20px}.survey-container .required-plugins-form .third-party-required-plugins-list li,.survey-container .required-plugins-form .manual-required-plugins-list li,.survey-container .install-plugins-form .third-party-required-plugins-list li,.survey-container .install-plugins-form .manual-required-plugins-list li{font-size:var(--st-font-size-xs);line-height:var(--st-font-line-height-xl)}.survey-container h1{text-align:left;padding-bottom:35px}.survey-container .row-label{margin-bottom:20px}.survey-container .survey-fields-wrap{display:grid;grid-template-columns:1fr 1fr;grid-gap:15px;margin-bottom:20px}.survey-container .survey-text-input{background:var(--st-background-primary);border:1px solid var(--st-border-color);border-radius:var(--st-border-radius-3);padding:10px 15px;width:100%}.survey-container .survey-text-input::-moz-placeholder{color:var(--st-color-placeholder)}.survey-container .survey-text-input::placeholder{color:var(--st-color-placeholder)}.survey-container .survey-text-input:focus{border-color:var(--st-color-accent)}.survey-container .survey-select-input{border:1px solid var(--st-border-color);border-radius:var(--st-border-radius-3);padding:10px 15px;width:100%;color:#2c3338}.survey-container .survey-select-input option:not(:first-of-type){color:#2c3338}.survey-container .survey-select-input::-moz-placeholder{color:var(--st-color-placeholder)}.survey-container .survey-select-input::placeholder{color:var(--st-color-placeholder)}.survey-container .survey-select-input:focus{border-color:var(--st-color-accent)}.survey-container .survey-select-input:hover{color:#2c3338}.survey-container .survey-select-input.initial{color:var(--st-color-placeholder)}.survey-container .hidden-section .survey-advanced-section{visibility:hidden}.survey-container .survey-form-advanced-wrapper .advanced-options-icons{cursor:pointer;display:flex}.survey-container .survey-form-advanced-wrapper .row-label{display:flex;align-items:center;align-content:center;grid-gap:10px}.survey-container .survey-form-advanced-wrapper ul{margin:0;padding:0}.survey-container .survey-form-advanced-wrapper li{margin-bottom:20px;display:flex;align-items:center;align-content:stretch;grid-gap:10px}.survey-container .survey-form-advanced-wrapper li:last-child{margin-bottom:0}.survey-container .survey-form-advanced-wrapper li input{margin:0;border:1px solid var(--st-color-body);border-radius:var(--st-border-radius-3)}.survey-container .survey-form-advanced-wrapper li.theme-check{margin-left:2em}.survey-container .survey-form-advanced-wrapper li label{font-size:var(--st-font-size-xs);line-height:var(--st-font-line-height-xs);color:var(--st-color-body)}.survey-container .survey-form-advanced-wrapper svg{cursor:pointer}.survey-container .submit-survey-btn.button-text{padding:15px 32px;width:100%;color:var(--st-color-white);background:var(--st-color-accent);border:none;cursor:pointer;margin-top:3em;align-content:center;grid-gap:15px;border-radius:var(--st-border-radius-4);font-weight:var(--st-font-weight-bold);font-size:15px}.survey-container .stc-tooltip-content{min-width:310px;text-align:left;line-height:1.4}.survey-container .requirement-check-wrap .current-php-version,.survey-container .requirement-check-wrap .current-file-system-permissions{margin-top:10px}.survey-container .requirement-check-wrap button.submit-survey-btn:disabled{background:var(--st-color-light-gray);color:var(--st-color-placeholder);cursor:not-allowed}.survey-container .requirement-check-wrap button.submit-survey-btn:disabled svg path{fill:var(--st-color-placeholder)}.survey-container .requirement-check-wrap .requirement-check-list{list-style:auto;margin:10px 20px}.survey-container .requirement-check-wrap .requirement-check-list li{font-size:var(--st-font-size-xs);line-height:var(--st-font-line-height-l)}.survey-container .requirement-check-wrap .requirement-check-list li p{color:var(--st-color-white)}.survey-container .requirement-check-wrap .requirement-check-list .requirement-list-item{display:flex;align-content:center;align-items:center;grid-gap:10px}.survey-container .requirement-check-wrap .requirement-check-list .requirement-list-item .dashicons-yes{color:var(--st-color-success, #39b54a)}.survey-container .requirement-check-wrap .requirement-check-list .requirement-list-item .dashicons-no{color:var(--st-color-error, #d72b3f)}.survey-container .requirement-check-wrap .requirement-check-list .stc-tooltip{display:flex}.survey-container .requirement-check-wrap .requirement-check-list .stc-tooltip .stc-tooltip-content{min-width:400px}.survey-container .requirement-check-wrap .requirement-check-list .stc-tooltip .stc-tooltip-content ul{list-style:auto;margin:6px 17px}.survey-container .requirement-check-wrap .requirement-check-list .stc-tooltip .stc-tooltip-content li{line-height:var(--st-font-line-height-s)}.starter-templates-ai-steps p.subscription-agreement-text{display:block;font-size:var(--st-font-size-xs);margin-top:24px;text-align:center}
.page-builder-screen-wrap .page-builder-wrap{margin:0 auto;max-width:800px;padding:0 20px;display:grid;-moz-column-gap:16px;column-gap:16px;justify-content:center;grid-auto-columns:minmax(0, 1fr);grid-auto-flow:column;align-items:center}#wpbody{padding-top:0 !important}
.page-builder-screen-wrap .page-builder-wrap{margin-top:40px;padding:0 20px;display:flex;justify-content:center;align-items:center}.page-builder-screen-wrap .image-wrap{padding-bottom:15px;display:inline-flex;cursor:pointer;box-sizing:border-box;border-radius:var(--st-border-radius-2);transition:all linear .2s;justify-content:center;align-items:center}.page-builder-screen-wrap .image-wrap img{width:100%;max-width:64px;border-radius:50%}.page-builder-screen-wrap .label-name{color:#475569}.page-builder-screen-wrap .page-builder-item{padding:24px;width:160px;height:150px;border-radius:var(--st-border-radius-4);cursor:pointer;transition:all linear .2s;background:var(--st-background-primary);flex-direction:column;justify-content:space-between !important;box-shadow:0px 1px 2px 0px rgba(0,0,0,0.0509803922)}.page-builder-screen-wrap .page-builder-item:hover,.page-builder-screen-wrap .page-builder-item:focus{transform:translateY(-1px);box-shadow:0px 16px 32px -12px rgba(149,160,178,0.3215686275);border-color:var(--st-color-white)}.page-builder-screen-wrap .zipwp-authorize-wrap{margin-top:20px}
body{--st-color-accent: #2563eb;--st-color-accent-hover: #1d4ed8;--st-color-heading: #1f2937;--st-color-body: #4b5563;--st-color-light-gray: #e5e7eb;--st-color-placeholder: #6b7280;--st-color-white: #ffffff;--st-color-favorite: #e91e63;--st-background-secondary: #f7f7f9;--st-background-primary: #ffffff;--st-background-light: #f9fafb;--st-tooltip-background: #020617;--st-font-size-xxl: 30px;--st-font-size-xl: 24px;--st-font-size-l: 20px;--st-font-size-m: 18px;--st-font-size-s: 16px;--st-font-size-xs: 14px;--st-font-weight-extra-bold: 600;--st-font-weight-bold: 500;--st-font-weight-normal: 400;--st-font-line-height-xl: 36px;--st-font-line-height-l: 32px;--st-font-line-height-m: 28px;--st-font-line-height-s: 24px;--st-font-line-height-xs: 20px;--st-border-color: #d1d5db;--st-border-radius-6: 6px;--st-border-radius-4: 4px;--st-border-radius-3: 3px;--st-border-radius-2: 2px;--st-border-radius-1: 1px}.zw-xxs-medium{font-size:.625rem;font-weight:500;line-height:.75rem}.zw-xs-normal{font-size:.75rem;font-weight:400;line-height:1rem}.zw-xs-medium{font-size:.75rem;font-weight:500;line-height:1rem}.zw-xs-semibold{font-size:.75rem;font-weight:600;line-height:1rem}.zw-sm-normal{font-size:.875rem;font-weight:400;line-height:1.25rem}.zw-sm-medium{font-size:.875rem;font-weight:500;line-height:1.25rem}.zw-sm-semibold{font-size:.875rem;font-weight:600;line-height:1.25rem}.zw-base-normal{font-size:1rem;font-weight:400;line-height:1.5rem}.zw-base-medium{font-size:1rem;font-weight:500;line-height:1.5rem}.zw-base-semibold{font-size:1rem;font-weight:600;line-height:1.5rem}.zw-base-bold{font-size:1rem;font-weight:700;line-height:1.5rem}.zw-h1{font-size:1.875rem;font-weight:700;line-height:2.25rem;color:var(--app-heading)}.zw-h2{font-size:1.5rem;font-weight:600;line-height:2rem;color:var(--app-heading)}.zw-h3{font-size:1.25rem;font-weight:600;line-height:1.25rem;color:var(--app-heading)}.zw-h4{font-size:1.125rem;font-weight:700;line-height:1.75rem;color:var(--app-heading)}.zw-h5{font-size:1rem;font-weight:600;line-height:1rem;color:var(--app-heading)}.zw-h6{font-size:.875rem;font-weight:600;line-height:.875rem;color:var(--app-heading)}.whats-new-rss-flyout{font-family:"Figtree",sans-serif !important}.whats-new-rss-flyout.closed{visibility:hidden}.whats-new-rss-flyout .whats-new-rss-flyout-contents .whats-new-rss-falyout-inner-content .whats-new-rss-flyout-inner-content-item{padding:40px 24px !important}.whats-new-rss-notification-badge{top:-12px !important;right:-8px !important}*,::before,::after{--tw-border-spacing-x: 0;--tw-border-spacing-y: 0;--tw-translate-x: 0;--tw-translate-y: 0;--tw-rotate: 0;--tw-skew-x: 0;--tw-skew-y: 0;--tw-scale-x: 1;--tw-scale-y: 1;--tw-pan-x: ;--tw-pan-y: ;--tw-pinch-zoom: ;--tw-scroll-snap-strictness: proximity;--tw-gradient-from-position: ;--tw-gradient-via-position: ;--tw-gradient-to-position: ;--tw-ordinal: ;--tw-slashed-zero: ;--tw-numeric-figure: ;--tw-numeric-spacing: ;--tw-numeric-fraction: ;--tw-ring-inset: ;--tw-ring-offset-width: 0px;--tw-ring-offset-color: #fff;--tw-ring-color: rgb(59 130 246 / 0.5);--tw-ring-offset-shadow: 0 0 #0000;--tw-ring-shadow: 0 0 #0000;--tw-shadow: 0 0 #0000;--tw-shadow-colored: 0 0 #0000;--tw-blur: ;--tw-brightness: ;--tw-contrast: ;--tw-grayscale: ;--tw-hue-rotate: ;--tw-invert: ;--tw-saturate: ;--tw-sepia: ;--tw-drop-shadow: ;--tw-backdrop-blur: ;--tw-backdrop-brightness: ;--tw-backdrop-contrast: ;--tw-backdrop-grayscale: ;--tw-backdrop-hue-rotate: ;--tw-backdrop-invert: ;--tw-backdrop-opacity: ;--tw-backdrop-saturate: ;--tw-backdrop-sepia: }::backdrop{--tw-border-spacing-x: 0;--tw-border-spacing-y: 0;--tw-translate-x: 0;--tw-translate-y: 0;--tw-rotate: 0;--tw-skew-x: 0;--tw-skew-y: 0;--tw-scale-x: 1;--tw-scale-y: 1;--tw-pan-x: ;--tw-pan-y: ;--tw-pinch-zoom: ;--tw-scroll-snap-strictness: proximity;--tw-gradient-from-position: ;--tw-gradient-via-position: ;--tw-gradient-to-position: ;--tw-ordinal: ;--tw-slashed-zero: ;--tw-numeric-figure: ;--tw-numeric-spacing: ;--tw-numeric-fraction: ;--tw-ring-inset: ;--tw-ring-offset-width: 0px;--tw-ring-offset-color: #fff;--tw-ring-color: rgb(59 130 246 / 0.5);--tw-ring-offset-shadow: 0 0 #0000;--tw-ring-shadow: 0 0 #0000;--tw-shadow: 0 0 #0000;--tw-shadow-colored: 0 0 #0000;--tw-blur: ;--tw-brightness: ;--tw-contrast: ;--tw-grayscale: ;--tw-hue-rotate: ;--tw-invert: ;--tw-saturate: ;--tw-sepia: ;--tw-drop-shadow: ;--tw-backdrop-blur: ;--tw-backdrop-brightness: ;--tw-backdrop-contrast: ;--tw-backdrop-grayscale: ;--tw-backdrop-hue-rotate: ;--tw-backdrop-invert: ;--tw-backdrop-opacity: ;--tw-backdrop-saturate: ;--tw-backdrop-sepia: }.container{width:100%}@media(min-width: 640px){.container{max-width:640px}}@media(min-width: 768px){.container{max-width:768px}}@media(min-width: 1024px){.container{max-width:1024px}}@media(min-width: 1280px){.container{max-width:1280px}}@media(min-width: 1536px){.container{max-width:1536px}}.sr-only{position:absolute;width:1px;height:1px;padding:0;margin:-1px;overflow:hidden;clip:rect(0, 0, 0, 0);white-space:nowrap;border-width:0}.pointer-events-none{pointer-events:none}.visible{visibility:visible}.invisible{visibility:hidden}.fixed{position:fixed}.absolute{position:absolute}.relative{position:relative}.inset-0{inset:0px}.-top-1{top:-0.25rem}.bottom-0{bottom:0px}.bottom-28{bottom:7rem}.bottom-\[18\%\]{bottom:18%}.left-0{left:0px}.left-1\/2{left:50%}.right-0{right:0px}.right-20{right:5rem}.right-4{right:1rem}.top-0{top:0px}.top-4{top:1rem}.z-10{z-index:10}.z-50{z-index:50}.z-\[1\]{z-index:1}.z-\[99999999\]{z-index:99999999}.\!m-0{margin:0px !important}.m-0{margin:0px}.mx-0{margin-left:0px;margin-right:0px}.mx-auto{margin-left:auto;margin-right:auto}.my-2{margin-top:.5rem;margin-bottom:.5rem}.my-6{margin-top:1.5rem;margin-bottom:1.5rem}.\!mb-1{margin-bottom:.25rem !important}.\!mb-2{margin-bottom:.5rem !important}.\!mt-1{margin-top:.25rem !important}.\!mt-5{margin-top:1.25rem !important}.mb-1{margin-bottom:.25rem}.mb-2{margin-bottom:.5rem}.mb-2\.5{margin-bottom:.625rem}.mb-4{margin-bottom:1rem}.mb-5{margin-bottom:1.25rem}.mb-6{margin-bottom:1.5rem}.mb-\[60px\]{margin-bottom:60px}.ml-2{margin-left:.5rem}.ml-auto{margin-left:auto}.mr-0{margin-right:0px}.mt-1{margin-top:.25rem}.mt-10{margin-top:2.5rem}.mt-2{margin-top:.5rem}.mt-3{margin-top:.75rem}.mt-4{margin-top:1rem}.mt-6{margin-top:1.5rem}.mt-auto{margin-top:auto}.block{display:block}.inline-block{display:inline-block}.inline{display:inline}.flex{display:flex}.inline-flex{display:inline-flex}.table{display:table}.grid{display:grid}.hidden{display:none}.size-4{width:1rem;height:1rem}.size-5{width:1.25rem;height:1.25rem}.h-10{height:2.5rem}.h-11{height:2.75rem}.h-12{height:3rem}.h-2{height:.5rem}.h-2\.5{height:.625rem}.h-3{height:.75rem}.h-4{height:1rem}.h-5{height:1.25rem}.h-6{height:1.5rem}.h-7{height:1.75rem}.h-8{height:2rem}.h-9{height:2.25rem}.h-\[0\.875rem\]{height:.875rem}.h-\[14px\]{height:14px}.h-\[2\.625rem\]{height:2.625rem}.h-\[24px\]{height:24px}.h-\[44px\]{height:44px}.h-\[50px\]{height:50px}.h-auto{height:auto}.h-full{height:100%}.max-h-60{max-height:15rem}.min-h-full{min-height:100%}.w-10{width:2.5rem}.w-12{width:3rem}.w-16{width:4rem}.w-2{width:.5rem}.w-2\.5{width:.625rem}.w-20{width:5rem}.w-3{width:.75rem}.w-36{width:9rem}.w-4{width:1rem}.w-48{width:12rem}.w-5{width:1.25rem}.w-6{width:1.5rem}.w-60{width:15rem}.w-7{width:1.75rem}.w-8{width:2rem}.w-80{width:20rem}.w-9{width:2.25rem}.w-\[0\.875rem\]{width:.875rem}.w-\[14px\]{width:14px}.w-\[1700px\]{width:1700px}.w-\[18\.25rem\]{width:18.25rem}.w-\[24px\]{width:24px}.w-\[390px\]{width:390px}.w-fit{width:-moz-fit-content;width:fit-content}.w-full{width:100%}.min-w-\[50px\]{min-width:50px}.\!max-w-\[55rem\]{max-width:55rem !important}.max-w-\[104px\]{max-width:104px}.max-w-\[320px\]{max-width:320px}.max-w-\[356px\]{max-width:356px}.max-w-\[35rem\]{max-width:35rem}.max-w-container{max-width:800px}.max-w-full{max-width:100%}.flex-1{flex:1 1 0%}.flex-shrink-0{flex-shrink:0}.\!shrink-0{flex-shrink:0 !important}.shrink-0{flex-shrink:0}.grow{flex-grow:1}.-translate-x-1\/2{--tw-translate-x: -50%;transform:translate(var(--tw-translate-x), var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))}.translate-x-0{--tw-translate-x: 0px;transform:translate(var(--tw-translate-x), var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))}.translate-x-5{--tw-translate-x: 1.25rem;transform:translate(var(--tw-translate-x), var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))}.translate-x-\[0\.15rem\]{--tw-translate-x: 0.15rem;transform:translate(var(--tw-translate-x), var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))}.translate-x-\[1\.15rem\]{--tw-translate-x: 1.15rem;transform:translate(var(--tw-translate-x), var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))}.translate-y-0{--tw-translate-y: 0px;transform:translate(var(--tw-translate-x), var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))}.translate-y-1\/2{--tw-translate-y: 50%;transform:translate(var(--tw-translate-x), var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))}.translate-y-4{--tw-translate-y: 1rem;transform:translate(var(--tw-translate-x), var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))}.rotate-180{--tw-rotate: 180deg;transform:translate(var(--tw-translate-x), var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))}.scale-100{--tw-scale-x: 1;--tw-scale-y: 1;transform:translate(var(--tw-translate-x), var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))}.scale-95{--tw-scale-x: .95;--tw-scale-y: .95;transform:translate(var(--tw-translate-x), var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))}.transform{transform:translate(var(--tw-translate-x), var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))}@keyframes pulse{50%{opacity:.5}}.animate-pulse{animation:pulse 2s cubic-bezier(0.4, 0, 0.6, 1) infinite}@keyframes spin{to{transform:rotate(360deg)}}.animate-spin{animation:spin 1s linear infinite}.cursor-default{cursor:default}.cursor-not-allowed{cursor:not-allowed}.cursor-pointer{cursor:pointer}.select-none{-webkit-user-select:none;-moz-user-select:none;user-select:none}.resize{resize:both}.auto-rows-\[36px\]{grid-auto-rows:36px}.auto-rows-auto{grid-auto-rows:auto}.grid-cols-1{grid-template-columns:repeat(1, minmax(0, 1fr))}.grid-cols-5{grid-template-columns:repeat(5, minmax(0, 1fr))}.grid-cols-\[1fr_min-content\]{grid-template-columns:1fr min-content}.flex-row{flex-direction:row}.flex-col{flex-direction:column}.place-content-center{place-content:center}.items-start{align-items:flex-start}.items-center{align-items:center}.justify-start{justify-content:flex-start}.justify-end{justify-content:flex-end}.justify-center{justify-content:center}.justify-between{justify-content:space-between}.\!gap-2{gap:.5rem !important}.gap-1{gap:.25rem}.gap-1\.5{gap:.375rem}.gap-2{gap:.5rem}.gap-3{gap:.75rem}.gap-4{gap:1rem}.gap-5{gap:1.25rem}.gap-6{gap:1.5rem}.gap-8{gap:2rem}.gap-x-8{-moz-column-gap:2rem;column-gap:2rem}.gap-y-5{row-gap:1.25rem}.space-x-2>:not([hidden])~:not([hidden]){--tw-space-x-reverse: 0;margin-right:calc(.5rem*var(--tw-space-x-reverse));margin-left:calc(.5rem*(1 - var(--tw-space-x-reverse)))}.space-x-3>:not([hidden])~:not([hidden]){--tw-space-x-reverse: 0;margin-right:calc(.75rem*var(--tw-space-x-reverse));margin-left:calc(.75rem*(1 - var(--tw-space-x-reverse)))}.space-y-1>:not([hidden])~:not([hidden]){--tw-space-y-reverse: 0;margin-top:calc(.25rem*(1 - var(--tw-space-y-reverse)));margin-bottom:calc(.25rem*var(--tw-space-y-reverse))}.space-y-2>:not([hidden])~:not([hidden]){--tw-space-y-reverse: 0;margin-top:calc(.5rem*(1 - var(--tw-space-y-reverse)));margin-bottom:calc(.5rem*var(--tw-space-y-reverse))}.space-y-3>:not([hidden])~:not([hidden]){--tw-space-y-reverse: 0;margin-top:calc(.75rem*(1 - var(--tw-space-y-reverse)));margin-bottom:calc(.75rem*var(--tw-space-y-reverse))}.space-y-4>:not([hidden])~:not([hidden]){--tw-space-y-reverse: 0;margin-top:calc(1rem*(1 - var(--tw-space-y-reverse)));margin-bottom:calc(1rem*var(--tw-space-y-reverse))}.space-y-5>:not([hidden])~:not([hidden]){--tw-space-y-reverse: 0;margin-top:calc(1.25rem*(1 - var(--tw-space-y-reverse)));margin-bottom:calc(1.25rem*var(--tw-space-y-reverse))}.space-y-6>:not([hidden])~:not([hidden]){--tw-space-y-reverse: 0;margin-top:calc(1.5rem*(1 - var(--tw-space-y-reverse)));margin-bottom:calc(1.5rem*var(--tw-space-y-reverse))}.space-y-8>:not([hidden])~:not([hidden]){--tw-space-y-reverse: 0;margin-top:calc(2rem*(1 - var(--tw-space-y-reverse)));margin-bottom:calc(2rem*var(--tw-space-y-reverse))}.\!divide-y>:not([hidden])~:not([hidden]){--tw-divide-y-reverse: 0 !important;border-top-width:calc(1px*(1 - var(--tw-divide-y-reverse))) !important;border-bottom-width:calc(1px*var(--tw-divide-y-reverse)) !important}.divide-x-0>:not([hidden])~:not([hidden]){--tw-divide-x-reverse: 0;border-right-width:calc(0px*var(--tw-divide-x-reverse));border-left-width:calc(0px*(1 - var(--tw-divide-x-reverse)))}.divide-solid>:not([hidden])~:not([hidden]){border-style:solid}.\!divide-border-primary>:not([hidden])~:not([hidden]){--tw-divide-opacity: 1 !important;border-color:rgb(209 213 219/var(--tw-divide-opacity)) !important}.overflow-auto{overflow:auto}.overflow-hidden{overflow:hidden}.overflow-y-auto{overflow-y:auto}.truncate{overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.whitespace-nowrap{white-space:nowrap}.whitespace-pre{white-space:pre}.rounded{border-radius:.25rem}.rounded-full{border-radius:9999px}.rounded-lg{border-radius:.5rem}.rounded-md{border-radius:.375rem}.rounded-sm{border-radius:.125rem}.rounded-xl{border-radius:.75rem}.rounded-t-lg{border-top-left-radius:.5rem;border-top-right-radius:.5rem}.border{border-width:1px}.border-0{border-width:0px}.border-2{border-width:2px}.border-b-0{border-bottom-width:0px}.border-t{border-top-width:1px}.border-solid{border-style:solid}.border-\[\#FB7E0A1F\]{border-color:rgba(251,126,10,0.1215686275)}.border-accent-st{--tw-border-opacity: 1;border-color:rgb(61 69 146/var(--tw-border-opacity))}.border-blue-500{--tw-border-opacity: 1;border-color:rgb(59 130 246/var(--tw-border-opacity))}.border-border-primary{--tw-border-opacity: 1;border-color:rgb(209 213 219/var(--tw-border-opacity))}.border-border-secondary{--tw-border-opacity: 1;border-color:rgb(107 114 128/var(--tw-border-opacity))}.border-border-tertiary{--tw-border-opacity: 1;border-color:rgb(216 223 233/var(--tw-border-opacity))}.border-button-disabled{--tw-border-opacity: 1;border-color:rgb(229 231 235/var(--tw-border-opacity))}.border-classic-button{--tw-border-opacity: 1;border-color:rgb(36 99 235/var(--tw-border-opacity))}.border-slate-200{--tw-border-opacity: 1;border-color:rgb(226 232 240/var(--tw-border-opacity))}.border-transparent{border-color:rgba(0,0,0,0)}.border-white{--tw-border-opacity: 1;border-color:rgb(255 255 255/var(--tw-border-opacity))}.border-zip-app-inactive-icon{--tw-border-opacity: 1;border-color:rgb(148 163 184/var(--tw-border-opacity))}.border-zip-dark-theme-border{--tw-border-opacity: 1;border-color:rgb(51 62 82/var(--tw-border-opacity))}.\!bg-accent-st{--tw-bg-opacity: 1 !important;background-color:rgb(61 69 146/var(--tw-bg-opacity)) !important}.\!bg-border-tertiary{--tw-bg-opacity: 1 !important;background-color:rgb(216 223 233/var(--tw-bg-opacity)) !important}.\!bg-classic-button{--tw-bg-opacity: 1 !important;background-color:rgb(36 99 235/var(--tw-bg-opacity)) !important}.\!bg-transparent{background-color:rgba(0,0,0,0) !important}.bg-\[\#F6FAFE\]{--tw-bg-opacity: 1;background-color:rgb(246 250 254/var(--tw-bg-opacity))}.bg-\[\#FB7E0A0F\]{background-color:rgba(251,126,10,0.0588235294)}.bg-accent-st{--tw-bg-opacity: 1;background-color:rgb(61 69 146/var(--tw-bg-opacity))}.bg-accent-st-secondary{--tw-bg-opacity: 1;background-color:rgb(37 99 235/var(--tw-bg-opacity))}.bg-background-primary{--tw-bg-opacity: 1;background-color:rgb(255 255 255/var(--tw-bg-opacity))}.bg-border-tertiary{--tw-bg-opacity: 1;background-color:rgb(216 223 233/var(--tw-bg-opacity))}.bg-browser-bar{--tw-bg-opacity: 1;background-color:rgb(250 250 250/var(--tw-bg-opacity))}.bg-button-disabled{--tw-bg-opacity: 1;background-color:rgb(229 231 235/var(--tw-bg-opacity))}.bg-classic-button{--tw-bg-opacity: 1;background-color:rgb(36 99 235/var(--tw-bg-opacity))}.bg-credit-warning{--tw-bg-opacity: 1;background-color:rgb(251 126 10/var(--tw-bg-opacity))}.bg-gray-300{--tw-bg-opacity: 1;background-color:rgb(209 213 219/var(--tw-bg-opacity))}.bg-inherit{background-color:inherit}.bg-st-background-secondary{--tw-bg-opacity: 1;background-color:rgb(247 247 249/var(--tw-bg-opacity))}.bg-transparent{background-color:rgba(0,0,0,0)}.bg-white{--tw-bg-opacity: 1;background-color:rgb(255 255 255/var(--tw-bg-opacity))}.bg-zip-app-heading{--tw-bg-opacity: 1;background-color:rgb(15 23 42/var(--tw-bg-opacity))}.bg-zip-dark-theme-border{--tw-bg-opacity: 1;background-color:rgb(51 62 82/var(--tw-bg-opacity))}.bg-opacity-75{--tw-bg-opacity: 0.75}.bg-gradient-1{background-image:linear-gradient(90deg, #B809A7 0%, #E90B76 46.88%, #FC8536 100%)}.bg-gradient-to-r{background-image:linear-gradient(to right, var(--tw-gradient-stops))}.from-gradient-color-1{--tw-gradient-from: #B809A7 var(--tw-gradient-from-position);--tw-gradient-to: rgb(184 9 167 / 0) var(--tw-gradient-to-position);--tw-gradient-stops: var(--tw-gradient-from), var(--tw-gradient-to)}.via-blue-500{--tw-gradient-to: rgb(59 130 246 / 0) var(--tw-gradient-to-position);--tw-gradient-stops: var(--tw-gradient-from), #3b82f6 var(--tw-gradient-via-position), var(--tw-gradient-to)}.via-gradient-color-2{--tw-gradient-to: rgb(233 11 118 / 0) var(--tw-gradient-to-position);--tw-gradient-stops: var(--tw-gradient-from), #E90B76 var(--tw-gradient-via-position), var(--tw-gradient-to)}.via-46\.88{--tw-gradient-via-position: 46.88%}.to-gradient-color-3{--tw-gradient-to: #FC8536 var(--tw-gradient-to-position)}.bg-clip-text{-webkit-background-clip:text;background-clip:text}.\!fill-none{fill:none !important}.stroke-1{stroke-width:1}.stroke-2{stroke-width:2}.object-contain{-o-object-fit:contain;object-fit:contain}.p-0{padding:0px}.p-0\.5{padding:.125rem}.p-1{padding:.25rem}.p-2{padding:.5rem}.p-4{padding:1rem}.p-8{padding:2rem}.p-\[0\.1875rem\]{padding:.1875rem}.p-px{padding:1px}.px-1{padding-left:.25rem;padding-right:.25rem}.px-2{padding-left:.5rem;padding-right:.5rem}.px-3{padding-left:.75rem;padding-right:.75rem}.px-4{padding-left:1rem;padding-right:1rem}.px-5{padding-left:1.25rem;padding-right:1.25rem}.px-6{padding-left:1.5rem;padding-right:1.5rem}.px-8{padding-left:2rem;padding-right:2rem}.px-\[1rem\]{padding-left:1rem;padding-right:1rem}.py-0{padding-top:0px;padding-bottom:0px}.py-0\.5{padding-top:.125rem;padding-bottom:.125rem}.py-1{padding-top:.25rem;padding-bottom:.25rem}.py-2{padding-top:.5rem;padding-bottom:.5rem}.py-2\.5{padding-top:.625rem;padding-bottom:.625rem}.py-3{padding-top:.75rem;padding-bottom:.75rem}.py-4{padding-top:1rem;padding-bottom:1rem}.py-\[3px\]{padding-top:3px;padding-bottom:3px}.pb-10{padding-bottom:2.5rem}.pb-6{padding-bottom:1.5rem}.pb-8{padding-bottom:2rem}.pb-px{padding-bottom:1px}.pl-2{padding-left:.5rem}.pl-3{padding-left:.75rem}.pl-4{padding-left:1rem}.pl-5{padding-left:1.25rem}.pl-6{padding-left:1.5rem}.pr-10{padding-right:2.5rem}.pr-3{padding-right:.75rem}.pr-4{padding-right:1rem}.pr-5{padding-right:1.25rem}.pr-6{padding-right:1.5rem}.pr-9{padding-right:2.25rem}.pt-0{padding-top:0px}.pt-10{padding-top:2.5rem}.pt-3{padding-top:.75rem}.pt-4{padding-top:1rem}.pt-8{padding-top:2rem}.\!text-left{text-align:left !important}.text-left{text-align:left}.\!text-center{text-align:center !important}.text-center{text-align:center}.text-start{text-align:start}.font-sans{font-family:Figtree,sans-serif}.\!text-\[1\.75rem\]{font-size:1.75rem !important}.\!text-base{font-size:1rem !important;line-height:1.5rem !important}.\!text-sm{font-size:.875rem !important;line-height:1.25rem !important}.\!text-xs{font-size:.75rem !important;line-height:1rem !important}.text-2xl{font-size:1.5rem;line-height:2rem}.text-3xl{font-size:1.875rem;line-height:2.25rem}.text-\[0\.625rem\]{font-size:.625rem}.text-\[0\.9rem\]{font-size:.9rem}.text-\[15px\]{font-size:15px}.text-base{font-size:1rem;line-height:1.5rem}.text-sm{font-size:.875rem;line-height:1.25rem}.text-xl{font-size:1.25rem;line-height:1.75rem}.text-xs{font-size:.75rem;line-height:1rem}.\!font-normal{font-weight:400 !important}.\!font-semibold{font-weight:600 !important}.font-bold{font-weight:700}.font-medium{font-weight:500}.font-normal{font-weight:400}.font-semibold{font-weight:600}.capitalize{text-transform:capitalize}.\!leading-5{line-height:1.25rem !important}.\!leading-6{line-height:1.5rem !important}.leading-3{line-height:.75rem}.leading-4{line-height:1rem}.leading-5{line-height:1.25rem}.leading-6{line-height:1.5rem}.leading-7{line-height:1.75rem}.leading-8{line-height:2rem}.leading-9{line-height:2.25rem}.leading-\[0\.9375rem\]{line-height:.9375rem}.leading-\[15px\]{line-height:15px}.tracking-normal{letter-spacing:0em}.\!text-classic-button{--tw-text-opacity: 1 !important;color:rgb(36 99 235/var(--tw-text-opacity)) !important}.\!text-zip-app-heading{--tw-text-opacity: 1 !important;color:rgb(15 23 42/var(--tw-text-opacity)) !important}.\!text-zip-app-inactive-icon{--tw-text-opacity: 1 !important;color:rgb(148 163 184/var(--tw-text-opacity)) !important}.\!text-zip-body-text{--tw-text-opacity: 1 !important;color:rgb(71 85 105/var(--tw-text-opacity)) !important}.text-accent-st{--tw-text-opacity: 1;color:rgb(61 69 146/var(--tw-text-opacity))}.text-accent-st-secondary{--tw-text-opacity: 1;color:rgb(37 99 235/var(--tw-text-opacity))}.text-alert-error{--tw-text-opacity: 1;color:rgb(239 68 68/var(--tw-text-opacity))}.text-body-text{--tw-text-opacity: 1;color:rgb(55 65 81/var(--tw-text-opacity))}.text-button-disabled{--tw-text-opacity: 1;color:rgb(229 231 235/var(--tw-text-opacity))}.text-gray-900{--tw-text-opacity: 1;color:rgb(17 24 39/var(--tw-text-opacity))}.text-heading-text{--tw-text-opacity: 1;color:rgb(3 7 18/var(--tw-text-opacity))}.text-nav-active{--tw-text-opacity: 1;color:rgb(17 24 39/var(--tw-text-opacity))}.text-transparent{color:rgba(0,0,0,0)}.text-white{--tw-text-opacity: 1;color:rgb(255 255 255/var(--tw-text-opacity))}.text-zip-app-heading{--tw-text-opacity: 1;color:rgb(15 23 42/var(--tw-text-opacity))}.text-zip-app-inactive-icon{--tw-text-opacity: 1;color:rgb(148 163 184/var(--tw-text-opacity))}.text-zip-body-text{--tw-text-opacity: 1;color:rgb(71 85 105/var(--tw-text-opacity))}.text-zip-dark-theme-heading{--tw-text-opacity: 1;color:rgb(252 252 253/var(--tw-text-opacity))}.underline{text-decoration-line:underline}.no-underline{text-decoration-line:none}.opacity-0{opacity:0}.opacity-100{opacity:1}.opacity-25{opacity:.25}.opacity-50{opacity:.5}.opacity-70{opacity:.7}.opacity-75{opacity:.75}.shadow{--tw-shadow: 0 1px 3px 0 rgb(0 0 0 / 0.1), 0 1px 2px -1px rgb(0 0 0 / 0.1);--tw-shadow-colored: 0 1px 3px 0 var(--tw-shadow-color), 0 1px 2px -1px var(--tw-shadow-color);box-shadow:var(--tw-ring-offset-shadow, 0 0 rgba(0, 0, 0, 0)),var(--tw-ring-shadow, 0 0 rgba(0, 0, 0, 0)),var(--tw-shadow)}.shadow-card{--tw-shadow: 0px 24px 64px -16px rgba(0, 0, 0, 0.16);--tw-shadow-colored: 0px 24px 64px -16px var(--tw-shadow-color);box-shadow:var(--tw-ring-offset-shadow, 0 0 rgba(0, 0, 0, 0)),var(--tw-ring-shadow, 0 0 rgba(0, 0, 0, 0)),var(--tw-shadow)}.shadow-lg{--tw-shadow: 0 10px 15px -3px rgb(0 0 0 / 0.1), 0 4px 6px -4px rgb(0 0 0 / 0.1);--tw-shadow-colored: 0 10px 15px -3px var(--tw-shadow-color), 0 4px 6px -4px var(--tw-shadow-color);box-shadow:var(--tw-ring-offset-shadow, 0 0 rgba(0, 0, 0, 0)),var(--tw-ring-shadow, 0 0 rgba(0, 0, 0, 0)),var(--tw-shadow)}.shadow-md{--tw-shadow: 0 4px 6px -1px rgb(0 0 0 / 0.1), 0 2px 4px -2px rgb(0 0 0 / 0.1);--tw-shadow-colored: 0 4px 6px -1px var(--tw-shadow-color), 0 2px 4px -2px var(--tw-shadow-color);box-shadow:var(--tw-ring-offset-shadow, 0 0 rgba(0, 0, 0, 0)),var(--tw-ring-shadow, 0 0 rgba(0, 0, 0, 0)),var(--tw-shadow)}.shadow-sm{--tw-shadow: 0px 1px 2px 0px rgba(0, 0, 0, 0.05);--tw-shadow-colored: 0px 1px 2px 0px var(--tw-shadow-color);box-shadow:var(--tw-ring-offset-shadow, 0 0 rgba(0, 0, 0, 0)),var(--tw-ring-shadow, 0 0 rgba(0, 0, 0, 0)),var(--tw-shadow)}.shadow-template-preview{--tw-shadow: 0px 40px 120px -16px rgba(0, 0, 0, 0.30);--tw-shadow-colored: 0px 40px 120px -16px var(--tw-shadow-color);box-shadow:var(--tw-ring-offset-shadow, 0 0 rgba(0, 0, 0, 0)),var(--tw-ring-shadow, 0 0 rgba(0, 0, 0, 0)),var(--tw-shadow)}.shadow-xl{--tw-shadow: 0 20px 25px -5px rgb(0 0 0 / 0.1), 0 8px 10px -6px rgb(0 0 0 / 0.1);--tw-shadow-colored: 0 20px 25px -5px var(--tw-shadow-color), 0 8px 10px -6px var(--tw-shadow-color);box-shadow:var(--tw-ring-offset-shadow, 0 0 rgba(0, 0, 0, 0)),var(--tw-ring-shadow, 0 0 rgba(0, 0, 0, 0)),var(--tw-shadow)}.outline-none{outline:2px solid rgba(0,0,0,0);outline-offset:2px}.outline{outline-style:solid}.outline-1{outline-width:1px}.outline-offset-2{outline-offset:2px}.outline-accent-st-secondary{outline-color:#2563eb}.ring-1{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 rgba(0, 0, 0, 0))}.ring-black{--tw-ring-opacity: 1;--tw-ring-color: rgb(0 0 0 / var(--tw-ring-opacity))}.ring-opacity-5{--tw-ring-opacity: 0.05}.filter{filter:var(--tw-blur) var(--tw-brightness) var(--tw-contrast) var(--tw-grayscale) var(--tw-hue-rotate) var(--tw-invert) var(--tw-saturate) var(--tw-sepia) var(--tw-drop-shadow)}.backdrop-blur{--tw-backdrop-blur: blur(8px);-webkit-backdrop-filter:var(--tw-backdrop-blur) var(--tw-backdrop-brightness) var(--tw-backdrop-contrast) var(--tw-backdrop-grayscale) var(--tw-backdrop-hue-rotate) var(--tw-backdrop-invert) var(--tw-backdrop-opacity) var(--tw-backdrop-saturate) var(--tw-backdrop-sepia);backdrop-filter:var(--tw-backdrop-blur) var(--tw-backdrop-brightness) var(--tw-backdrop-contrast) var(--tw-backdrop-grayscale) var(--tw-backdrop-hue-rotate) var(--tw-backdrop-invert) var(--tw-backdrop-opacity) var(--tw-backdrop-saturate) var(--tw-backdrop-sepia)}.transition{transition-property:color,background-color,border-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,-webkit-backdrop-filter;transition-property:color,background-color,border-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,backdrop-filter;transition-property:color,background-color,border-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,backdrop-filter,-webkit-backdrop-filter;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:150ms}.transition-all{transition-property:all;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:150ms}.transition-colors{transition-property:color,background-color,border-color,text-decoration-color,fill,stroke;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:150ms}.transition-opacity{transition-property:opacity;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:150ms}.transition-transform{transition-property:transform;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:150ms}.duration-100{transition-duration:100ms}.duration-150{transition-duration:150ms}.duration-200{transition-duration:200ms}.duration-300{transition-duration:300ms}.duration-75{transition-duration:75ms}.ease-in{transition-timing-function:cubic-bezier(0.4, 0, 1, 1)}.ease-in-out{transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1)}.ease-out{transition-timing-function:cubic-bezier(0, 0, 0.2, 1)}#starter-templates-ai-root{font-size:16px;background:var(--st-background-primary);font-family:"Figtree",sans-serif;--wp-admin-theme-color: var( --st-color-accent );--wp-admin-theme-color-darker-10: var( --st-color-accent )}@media screen and (max-width: 1366px){.step-customizer{--sidebar-width: 342px}}@media screen and (min-width: 1367px){.step-customizer{--sidebar-width: 342px}}html.wp-toolbar{padding:0}.intelligent-starter-templates-onboarding #adminmenumain,.intelligent-starter-templates-onboarding #wpadminbar,.intelligent-starter-templates-onboarding #adminmenuback,.intelligent-starter-templates-onboarding #adminmenuwrap,.intelligent-starter-templates-onboarding #wpfooter{display:none}.intelligent-starter-templates-onboarding #wpcontent,.intelligent-starter-templates-onboarding.auto-fold #wpcontent{margin:0;padding:0}.intelligent-starter-templates-onboarding.appearance_page_starter-templates #wpbody-content{padding:0}body{overflow-y:hidden}body *{box-sizing:border-box}body * :focus{outline:none}::-webkit-scrollbar{width:8px}::-webkit-scrollbar-track{border-radius:0px}::-webkit-scrollbar-thumb{background:#d5d6d7;border-radius:0px}::-webkit-scrollbar-thumb:hover{background:#d1d2d3;cursor:pointer}#spectra-onboarding-ai :disabled,#spectra-onboarding-ai [data-disabled=true]{pointer-events:none;opacity:.7}#spectra-onboarding-ai div:has(>:disabled),#spectra-onboarding-ai div:has(>[data-disabled=true]){cursor:not-allowed !important}.st-link,a{cursor:pointer;text-decoration:none;color:var(--st-color-accent)}.st-link:hover,a:hover{color:var(--st-color-accent-hover)}.step-row{background:var(--st-background-primary);display:flex;overflow:hidden;height:calc(100vh - 60px)}.hide-sidebar .step-col-right{width:100%}.step-col-right{width:calc(100% - var(--sidebar-width));padding:0 2%;margin-left:var(--sidebar-width);transition:all 350ms linear}.step-col-left{width:var(--sidebar-width);display:flex;flex-direction:column;height:calc(100vh - 60px);position:absolute;inset:0;transition:transform 350ms linear;transform:translateX(0);box-shadow:1px 0px 3px rgba(0,0,0,.1),1px 0px 2px rgba(0,0,0,.06);z-index:9}.step-content{background:#f7f7f9;padding:5%;overflow-y:auto;flex:1;height:100%;border-radius:var(--st-border-radius-2)}.step-actions{padding:21px 45px;display:flex;justify-content:space-between;align-items:center;background:var(--st-background-primary);position:fixed;bottom:0;right:0;left:0;z-index:10;box-shadow:0px -4px 8px -3px rgba(0,0,0,.05),0px -2px 6px -2px rgba(0,0,0,.05)}.step-actions p{font-size:16px;color:#353852;margin:0}.step-customizer .ist-link{padding:0 0 15px 0;font-size:var(--st-font-size-xs);color:var(--st-color-body);display:flex;justify-content:center;align-items:center;width:-moz-fit-content;width:fit-content;margin:15px auto 0 auto}.step-customizer .step-row{height:100vh}.step-customizer .step-actions{padding:6% 8%;background:var(--st-background-primary);position:unset;bottom:0;right:0;left:0;border-radius:0 0 0 var(--st-border-radius-4);border-top:none;flex-wrap:wrap}.step-customizer .step-col-left{height:auto}.step-customizer .step-col-right{padding:0;position:relative}.step-col-right img{max-width:100%;height:auto}.step-actions .dashicons-arrow-left-alt{margin-right:5px}.step-actions .dashicons-arrow-right-alt{margin-left:5px}.astra-sites-ai-logo-wrap{color:var(--st-color-heading);margin-bottom:17px;margin-top:25px}.astra-sites-ai-logo-wrap,.astra-sites-ai-rangecontrol-wrap{width:100%}.ist-logo{--stc-logo-height: 44px;--stc-logo-width: 44px;cursor:pointer}.step-full-width .step-col{flex:1;text-align:center}.st-header-right{display:flex;align-items:center;justify-content:space-between}.st-search-box-fixed .step-header{position:static}.step-header{z-index:1;position:relative}.step-header a{color:var(--st-color-placeholder);text-decoration:none;display:flex;font-weight:var(--st-font-weight-bold);font-size:var(--st-font-size-s);line-height:var(--st-line-height-xs);align-items:center}.step-header a svg{fill:var(--st-color-placeholder)}.step-header a:hover,.step-header a:focus{color:var(--st-color-heading)}.step-header a:hover svg path,.step-header a:focus svg path{fill:var(--st-color-heading)}.step-header a:focus{outline:none;box-shadow:none}.step-header:focus{outline:none;box-shadow:none}body.step-import-site:not(.st-error) .step-header a{pointer-events:none;opacity:.7}body.step-import-site-done .step-header a{opacity:1 !important;pointer-events:visible !important}body.step-import-site-done .step-actions{display:none}.row{display:flex;align-items:center;justify-content:space-between}.row.center{justify-content:center}.row.full{flex:1}.step-header .row,.site-list-header .row{box-shadow:0px 6px 8px -3px rgba(0,0,0,.05),0px 4px 6px -2px rgba(0,0,0,.05);position:relative;z-index:1}.step-header .row>.col,.step-header .row>.right-col,.site-list-header .row>.col,.site-list-header .row>.right-col{pointer-events:auto}.step-header .row .branding-wrap,.site-list-header .row .branding-wrap{display:flex;align-items:center;justify-content:center;align-content:center;grid-gap:20px;padding:16px 24px;border-right:1px solid var(--st-border-color)}.step-header .row .exit-link,.site-list-header .row .exit-link{padding:26px 30px;border-left:1px solid var(--st-border-color)}.step-header .row .right-col,.site-list-header .row .right-col{display:flex;align-content:center;align-items:center}.step-header .row .back-to-main,.site-list-header .row .back-to-main{padding:26px 30px}.step-header .row .back-to-main svg,.site-list-header .row .back-to-main svg{cursor:pointer}.step-header .row .back-to-main:hover svg path,.step-header .row .back-to-main:focus svg path,.site-list-header .row .back-to-main:hover svg path,.site-list-header .row .back-to-main:focus svg path{fill:var(--st-color-heading)}.customizer-controls{height:calc(70vh - 230px);overflow-y:auto}.astra-sites-ai-rangecontrol-wrap .components-range-control__wrapper{margin-left:0}.astra-sites-ai-rangecontrol-wrap .components-input-control__input:focus+.components-input-control__backdrop{border-color:var(--st-color-accent);box-shadow:0 0 0 1px var(--st-color-accent)}.customize-license-validation{position:relative}.customize-license-validation .processing::before{color:var(--st-background-primary);font:normal 20px/0 dashicons}.customize-license-validation button.st-access-btn{display:inline-flex;align-items:center;justify-content:center;align-content:center;grid-gap:7px;margin-top:15px;margin-bottom:0}.customize-license-validation button.st-access-btn .st-get-access{height:12px}.customize-license-validation .license-wrap{display:grid;grid-template-columns:80% 20%;align-items:center;justify-items:end;border:1px solid var(--st-border-color);background:var(--st-background-primary);padding:5px;margin-top:30px;border-radius:var(--st-border-radius-2)}.customize-license-validation .license-wrap:focus-within{border:1px solid var(--st-color-accent)}.customize-license-validation .license-key-input{border:none;background:var(--st-background-primary);border-radius:var(--st-border-radius-4);padding:10px 10px;width:100%;height:38px}.customize-license-validation .license-key-input::-moz-placeholder{color:var(--st-color-placeholder)}.customize-license-validation .license-key-input::placeholder{color:var(--st-color-placeholder)}.customize-license-validation .license-key-input:focus{border:none;outline:0;box-shadow:none}.customize-license-validation .customer-notices{margin:10px 0}.customize-license-validation button.validate-btn{margin:0;border-radius:0px;background:var(--st-color-placeholder);width:unset;padding:12px;border-radius:var(--st-border-radius-2)}.customize-license-validation button.validate-btn svg{height:15px;width:15px}.customize-license-validation button.validate-btn svg path{fill:var(--st-color-white)}.customize-license-validation button.validate-btn:hover{background:var(--st-color-accent)}.customize-license-validation .license-error{border:1px solid var(--st-border-color);box-shadow:0 10px 15px -3px rgba(0,0,0,.1),0 4px 6px -2px rgba(0,0,0,.05);border-radius:var(--st-border-radius-4);margin-top:15px}.customize-license-validation .license-error .p-4{padding:1rem}.customize-license-validation .license-error .license-error-inner>div{display:flex}.customize-license-validation .license-error .license-error-inner{display:flex;align-items:flex-start;justify-content:space-between}.customize-license-validation .license-error .license-error-message p{margin-left:.75rem}.customize-license-validation .license-error .error-icon{display:flex}.customize-license-validation .license-error .error-icon svg{width:1.25rem;height:1.25rem}.customize-license-validation .license-error .error-icon.cross-icon svg{color:#eb3f3f}.customize-license-validation .license-error .error-icon.close-icon{margin-left:1rem}.customize-license-validation .license-error .error-icon.close-icon button{margin:0;padding:0;background:none;border:none;color:var(--st-color-body);cursor:pointer;height:15px;width:15px}.customize-license-validation .st-toaster{position:unset;margin-top:20px;width:100%}.ist-button{background:var(--st-color-accent);color:var(--st-background-primary);border-radius:var(--st-border-radius-4);padding:15px 32px;text-decoration:none}.ist-button:hover{background:var(--st-color-accent);color:var(--st-color-white)}.ist-button.ist-button-outline{background:var(--st-color-white);color:var(--st-color-accent);border:1px dashed var(--st-color-placeholder);width:100%;font-size:14px;align-items:center;flex-direction:column;justify-content:center;grid-gap:12px;padding:32px 10px}.ist-button.ist-button-outline:hover,.ist-button.ist-button-outline:focus{background:var(--st-background-primary);color:var(--st-color-accent);border-color:var(--st-color-accent)}.ist-button.ist-button-outline p{font-size:13px}.step-page-builder.st-step .row{padding:0;position:relative}.ist-link.disabled{pointer-events:none;opacity:.7}.ist-link.disabled.hidden-btn{opacity:0}.middle-content{margin:0;position:absolute;top:50%;left:50%;transform:translate(-50%, -50%)}.middle-content.middle-content-import{background:var(--st-background-primary);padding:30px;box-shadow:0px 4px 6px -2px rgba(0,0,0,.05),0px 10px 15px -3px rgba(0,0,0,.1);width:600px;border-radius:var(--st-border-radius-4)}.site-loading-skeleton{overflow-y:auto;height:100%}.site-loading-skeleton .MuiSkeleton-root{border-radius:var(--st-border-radius-2)}.d-flex-center-align{display:flex;align-items:center;justify-content:center}.d-flex-space-between{display:flex;justify-content:space-between;align-items:center;align-content:center}.starter-templates-ai-steps h1{font-size:var(--st-font-size-xxl);font-weight:var(--st-font-weight-extra-bold);margin:0;color:var(--st-color-heading);line-height:var(--st-font-line-height-xl)}.starter-templates-ai-steps h2{font-size:var(--st-font-size-xl);font-weight:var(--st-font-weight-bold);margin:0;color:var(--st-color-heading);line-height:var(--st-font-line-height-l)}.starter-templates-ai-steps h3{font-size:var(--st-font-size-l);font-weight:var(--st-font-weight-bold);margin:0;color:var(--st-color-heading);line-height:var(--st-font-line-height-m)}.starter-templates-ai-steps h4{font-size:var(--st-font-size-m);font-weight:var(--st-font-weight-bold);margin:0;color:var(--st-color-heading);line-height:var(--st-font-line-height-m)}.starter-templates-ai-steps h5{font-size:var(--st-font-size-s);font-weight:var(--st-font-weight-bold);margin:0;color:var(--st-color-heading);line-height:var(--st-font-line-height-s)}.starter-templates-ai-steps h6{font-size:var(--st-font-size-xs);font-weight:var(--st-font-weight-bold);margin:0;color:var(--st-color-heading);line-height:var(--st-font-line-height-xs)}.starter-templates-ai-steps p{font-size:var(--st-font-size-xs);color:var(--st-color-body);margin:0;font-weight:var(--st-font-weight-normal);line-height:var(--st-font-line-height-xs)}.starter-templates-ai-steps p.p-bold{font-weight:var(--st-font-weight-bold)}.starter-templates-ai-steps .button-text{font-size:var(--st-font-size-xs);font-weight:var(--st-font-weight-bold);color:var(--st-color-accent);line-height:var(--st-font-line-height-xs)}.starter-templates-ai-steps .placeholder{font-size:var(--st-font-size-xs);font-weight:var(--st-font-weight-normal);color:var(--st-color-placeholder);line-height:var(--st-font-line-height-xs)}.starter-templates-ai-steps .label-text{font-size:var(--st-font-size-s);font-weight:var(--st-font-weight-bold);color:var(--st-color-heading);line-height:var(--st-font-line-height-s)}.starter-templates-ai-steps .label-text.label-bold{font-weight:var(--st-font-weight-extra-bold)}.starter-templates-ai-steps .screen-description{margin:20px auto 40px;max-width:700px;color:#9ca3af}.starter-templates-ai-steps .ist-customizer-heading{margin-bottom:10px}.starter-templates-ai-steps .ist-secondary-heading{margin:25px 0 17px 0}.starter-templates-ai-steps .ist-fonts-description,.starter-templates-ai-steps .ist-colors-description{margin:2em 0 0 0}.starter-templates-ai-steps .ist-footer-note{font-size:12px}.starter-templates-ai-steps .customizer-header{background:var(--st-background-secondary);border-bottom:1px solid var(--st-border-color)}.starter-templates-ai-steps .customizer-header .header-name{padding:6% 9%;width:100%}.starter-templates-ai-steps .toggle-sidebar-wrap{display:none}.starter-templates-ai-steps .step-customizer .step-content{background-color:var(--st-background-secondary)}.starter-templates-ai-steps .step-customizer .hide-sidebar .step-col-left{transform:translateX(-100%)}.starter-templates-ai-steps .step-customizer .hide-sidebar .step-col-right{margin-left:0%;transition:margin-left 350ms linear}.starter-templates-ai-steps .step-customizer .hide-sidebar .toggle-sidebar-wrap{background:var(--st-color-accent)}.starter-templates-ai-steps .step-customizer .hide-sidebar .toggle-sidebar-wrap svg path{fill:var(--st-color-white)}.starter-templates-ai-steps .step-customizer .screen-description{margin:0}.starter-templates-ai-steps .step-customizer .toggle-sidebar-wrap{width:18px;background:#f4f5f6;box-shadow:1px 0px 3px rgba(0,0,0,.1),1px 0px 2px rgba(0,0,0,.06);border-radius:0px var(--st-border-radius-2) var(--st-border-radius-2) 0px;height:61px;display:flex;align-items:center;justify-content:center;position:absolute;left:100%;top:50%;transform:translateY(-50%);cursor:pointer}.starter-templates-ai-steps .step-customizer .toggle-sidebar-wrap svg{height:15px;width:15px}.starter-templates-ai-steps .step-customizer .toggle-sidebar-wrap svg path{fill:var(--st-color-placeholder)}.starter-templates-ai-steps .step-customizer .toggle-sidebar-wrap:hover{background:var(--st-color-accent)}.starter-templates-ai-steps .step-customizer .toggle-sidebar-wrap:hover svg path{fill:var(--st-color-white)}.starter-templates-ai-steps .step-customizer .logo-skip-info{padding:20px;background:var(--st-color-light-gray);border-radius:4px}.starter-templates-ai-steps .step-customizer .logo-skip-info p{margin-top:5px}.starter-templates-ai-steps .step-customizer .premium-notice{border:1px solid rgba(220,50,50,.568627451);background:rgba(220,50,50,.031372549);border-radius:var(--st-border-radius-2);padding:10px;color:#4b5563;font-size:var(--st-font-size-xs);margin-bottom:10px}.starter-templates-ai-steps .step-customizer .step-content.customize-typography-colors .step-controls{padding:0}.starter-templates-ai-steps .step-customizer .step-content.customize-typography-colors .colors-section,.starter-templates-ai-steps .step-customizer .step-content.customize-typography-colors .typography-section{padding:8%}.starter-templates-ai-steps .step-customizer .step-content.customize-typography-colors .colors-section{border-bottom:1px solid var(--st-border-color)}.starter-templates-ai-steps .step-customizer .customize-reset-btn{cursor:pointer}.starter-templates-ai-steps .step-customizer .customize-reset-btn.disabled{cursor:not-allowed;opacity:.5}.starter-templates-ai-steps .step-customizer .customize-reset-btn.active svg path{fill:var(--st-color-accent)}.step-customizer .starter-templates-ai-steps .step-content{padding:0;border-radius:0;border-bottom:none}.step-customizer .starter-templates-ai-steps .step-content .step-controls{padding:8%}.step-congrats .starter-templates-ai-steps .step-content{padding:4%}.step-congrats .starter-templates-ai-steps .step-row{height:calc(100vh - 62px)}#ist-bashcanvas{pointer-events:none;position:fixed;z-index:2;inset:0}#st-welcome-video,#st-information-video{width:770px;height:446px;left:0px;top:0px;border:15px solid var(--st-color-white);box-shadow:0px 10px 15px -2px rgba(0,0,0,.1),0px 4px 6px -2px rgba(0,0,0,.05);border-radius:var(--st-border-radius-4)}.ist-fadeinUp{animation:ist-fadeinUp 500ms ease-in-out}.st-rtl .ist-button svg{margin:0 0 0 12px}.st-rtl .ist-link svg{margin-right:10px}.st-rtl .control-reset{transform:rotateY(180deg)}.st-rtl .st-sync-library.loading svg{animation:rotate-alternate 2s infinite linear}.st-rtl .ist-link svg,.st-rtl .ist-button svg,.st-rtl .submit-survey-btn svg,.st-rtl .toggle-sidebar-wrap svg{transform:rotate(180deg)}.st-rtl .astra-sites-ai-rangecontrol-wrap .components-range-control__number{margin-left:16px !important;margin-right:0 !important}.stc-tooltip-content a{color:var(--st-color-white)}@keyframes rotate-alternate{from{transform:rotate(360deg)}to{transform:rotate(0deg)}}@keyframes ist-fadeinUp{0%{opacity:0;transform:translateY(10px)}100%{opacity:1;transform:translateY(0)}}.step-content.customize-business-logo .content-wrapper{animation:logo-screen-fadeIn 500ms}@keyframes logo-screen-fadeIn{0%{opacity:.3}100%{opacity:1}}.step-content.customize-typography-colors .content-wrapper{animation:colors-screen-fadeIn 500ms}@keyframes colors-screen-fadeIn{0%{opacity:.3}100%{opacity:1}}.step-content.customize-site-typography .content-wrapper{animation:typo-screen-fadeIn 500ms}@keyframes typo-screen-fadeIn{0%{opacity:.3}100%{opacity:1}}.step-content.congratulations .content-wrapper{animation:congrats-screen-fadeIn 500ms}@keyframes congrats-screen-fadeIn{0%{opacity:.3}100%{opacity:1}}.hide-scrollbar{scrollbar-width:none;-ms-overflow-style:none}.hide-scrollbar::-webkit-scrollbar{display:none}.gradient-border-bottom{text-align:center;border-bottom:5px solid rgba(0,0,0,0);-o-border-image:linear-gradient(90deg, #5a03ef 0% #fe5be4 100%);border-image:linear-gradient(90deg, #5a03ef 0% #fe5be4 100%);border-image-slice:1;width:100%;opacity:.5}.gradient-border-cover{position:relative}.gradient-border-cover::before{content:"";position:absolute;inset:0;border-radius:50px;padding:2px;background:linear-gradient(180deg, #5a03ef 0%, #fe5be4 100%);mask:linear-gradient(white 0 0) content-box,linear-gradient(white 0 0);-webkit-mask:linear-gradient(white 0 0) content-box,linear-gradient(white 0 0);-webkit-mask-composite:xor;mask-composite:exclude;pointer-events:none}.gradient-border-cover-button::before{border-radius:12px !important;padding:1px !important;inset:-1px}.input-focus-border:focus{border:2px solid #3d4592 !important}.step-customizer .st-toaster{display:flex;width:100%;max-width:100%}.st-page-builder-filter .stc-toggle-dropdown-selected .stc-logo{gap:8px}.st-page-builder-filter .stc-toggle-dropdown-selected .stc-logo-text{display:contents}.st-page-builder-filter .stc-toggle-dropdown-selected .stc-logo-text::after{content:"";width:8px;height:8px;display:block;border-radius:9999px;background:linear-gradient(90deg, #b809a7 0%, #e90b76 46.88%, #fc8536 100%);margin-top:-10px}.zw-tooltip{text-align:left;background:var(--st-tooltip-background);color:#fff;border-radius:6px}.zw-tooltip>.tippy-content{box-shadow:0px 4px 8px -2px rgba(9,30,66,.25),0px 0px 1px rgba(9,30,66,.31);padding:6px 12px;font-size:14px;font-weight:400;line-height:1.25rem}.zw-tooltip>.tippy-content a{color:#fff}.placeholder\:\!text-base::-moz-placeholder{font-size:1rem !important;line-height:1.5rem !important}.placeholder\:\!text-base::placeholder{font-size:1rem !important;line-height:1.5rem !important}.placeholder\:text-secondary-text::-moz-placeholder{--tw-text-opacity: 1;color:rgb(156 163 175/var(--tw-text-opacity))}.placeholder\:text-secondary-text::placeholder{--tw-text-opacity: 1;color:rgb(156 163 175/var(--tw-text-opacity))}.before\:visible::before{content:var(--tw-content);visibility:visible}.before\:absolute::before{content:var(--tw-content);position:absolute}.before\:h-2::before{content:var(--tw-content);height:.5rem}.before\:w-2::before{content:var(--tw-content);width:.5rem}.before\:\!rotate-45::before{content:var(--tw-content);--tw-rotate: 45deg !important;transform:translate(var(--tw-translate-x), var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y)) !important}.before\:bg-inherit::before{content:var(--tw-content);background-color:inherit}.before\:content-\[\'\'\]::before{--tw-content: "";content:var(--tw-content)}.hover\:\!bg-accent-st:hover{--tw-bg-opacity: 1 !important;background-color:rgb(61 69 146/var(--tw-bg-opacity)) !important}.hover\:bg-container-background:hover{--tw-bg-opacity: 1;background-color:rgb(240 244 250/var(--tw-bg-opacity))}.hover\:bg-white:hover{--tw-bg-opacity: 1;background-color:rgb(255 255 255/var(--tw-bg-opacity))}.hover\:bg-opacity-100:hover{--tw-bg-opacity: 1}.hover\:text-nav-active:hover{--tw-text-opacity: 1;color:rgb(17 24 39/var(--tw-text-opacity))}.focus\:outline-none:focus{outline:2px solid rgba(0,0,0,0);outline-offset:2px}.focus\:ring-1:focus{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 rgba(0, 0, 0, 0))}.focus\:ring-accent-st:focus{--tw-ring-opacity: 1;--tw-ring-color: rgb(61 69 146 / var(--tw-ring-opacity))}.focus-visible\:outline:focus-visible{outline-style:solid}.focus-visible\:outline-2:focus-visible{outline-width:2px}.focus-visible\:outline-offset-2:focus-visible{outline-offset:2px}.focus-visible\:ring-accent-st:focus-visible{--tw-ring-opacity: 1;--tw-ring-color: rgb(61 69 146 / var(--tw-ring-opacity))}.data-\[checked\]\:border-accent-st-secondary[data-checked]{--tw-border-opacity: 1;border-color:rgb(37 99 235/var(--tw-border-opacity))}.data-\[checked\]\:bg-accent-st-secondary[data-checked]{--tw-bg-opacity: 1;background-color:rgb(37 99 235/var(--tw-bg-opacity))}.group[data-checked] .group-data-\[checked\]\:opacity-100{opacity:1}@media(min-width: 640px){.sm\:my-8{margin-top:2rem;margin-bottom:2rem}.sm\:h-10{height:2.5rem}.sm\:w-8{width:2rem}.sm\:w-full{width:100%}.sm\:max-w-\[24rem\]{max-width:24rem}.sm\:max-w-\[29rem\]{max-width:29rem}.sm\:max-w-\[30rem\]{max-width:30rem}.sm\:max-w-\[32\.5rem\]{max-width:32.5rem}.sm\:max-w-\[35rem\]{max-width:35rem}.sm\:max-w-\[40rem\]{max-width:40rem}.sm\:translate-y-0{--tw-translate-y: 0px;transform:translate(var(--tw-translate-x), var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))}.sm\:scale-100{--tw-scale-x: 1;--tw-scale-y: 1;transform:translate(var(--tw-translate-x), var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))}.sm\:scale-95{--tw-scale-x: .95;--tw-scale-y: .95;transform:translate(var(--tw-translate-x), var(--tw-translate-y)) rotate(var(--tw-rotate)) skewX(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))}.sm\:items-center{align-items:center}.sm\:p-0{padding:0px}.sm\:text-sm{font-size:.875rem;line-height:1.25rem}.sm\:leading-6{line-height:1.5rem}}@media(min-width: 768px){.md\:grid-cols-1{grid-template-columns:repeat(1, minmax(0, 1fr))}.md\:grid-cols-2{grid-template-columns:repeat(2, minmax(0, 1fr))}}@media(min-width: 1024px){.lg\:max-w-\[800px\]{max-width:800px}.lg\:grid-cols-2{grid-template-columns:repeat(2, minmax(0, 1fr))}.lg\:pb-0{padding-bottom:0px}}.\[\&_\.components\\-base\\-control\\_\\_field\]\:mb-0 .components-base-control__field{margin-bottom:0px}.\[\&_\.components\\-range\\-control\\_\\_thumb-wrapper\]\:mt-2 .components-range-control__thumb-wrapper{margin-top:.5rem}.\[\&_\.components\\-range\\-control\\_\\_thumb-wrapper\]\:h-\[14px\] .components-range-control__thumb-wrapper{height:14px}.\[\&_\.components\\-range\\-control\\_\\_thumb-wrapper\]\:w-\[14px\] .components-range-control__thumb-wrapper{width:14px}.\[\&_\.components\\-range\\-control\\_\\_thumb-wrapper\]\:border .components-range-control__thumb-wrapper{border-width:1px}.\[\&_\.components\\-range\\-control\\_\\_thumb-wrapper\]\:border-solid .components-range-control__thumb-wrapper{border-style:solid}.\[\&_\.components\\-range\\-control\\_\\_thumb-wrapper\]\:border-white .components-range-control__thumb-wrapper{--tw-border-opacity: 1;border-color:rgb(255 255 255/var(--tw-border-opacity))}
