.invisible {visibility: hidden
}.fixed {position: fixed
}.absolute {position: absolute
}.relative {position: relative
}.inset-0 {inset: 0px
}.bottom-2 {bottom: 0.5rem
}.right-2 {right: 0.5rem
}.right-3 {right: 0.75rem
}.top-3 {top: 0.75rem
}.isolate {isolation: isolate
}.z-10 {z-index: 10
}.mx-0 {margin-left: 0px;margin-right: 0px
}.my-0 {margin-top: 0px;margin-bottom: 0px
}.mb-0 {margin-bottom: 0px
}.mt-1 {margin-top: 0.25rem
}.mt-2 {margin-top: 0.5rem
}.mt-3 {margin-top: 0.75rem
}.mt-5 {margin-top: 1.25rem
}.block {display: block
}.flex {display: flex
}.inline-flex {display: inline-flex
}.size-5 {width: 1.25rem;height: 1.25rem
}.size-6 {width: 1.5rem;height: 1.5rem
}.h-11 {height: 2.75rem
}.h-5 {height: 1.25rem
}.h-\[2\.625rem\] {height: 2.625rem
}.w-4 {width: 1rem
}.w-5 {width: 1.25rem
}.w-full {width: 100%
}.max-w-\[30rem\] {max-width: 30rem
}.flex-1 {flex: 1 1 0%
}@keyframes spin {to {transform: rotate(360deg)
    }
}.animate-spin {animation: spin 1s linear infinite
}.cursor-not-allowed {cursor: not-allowed
}.cursor-pointer {cursor: pointer
}.cursor-progress {cursor: progress
}.items-center {align-items: center
}.justify-start {justify-content: flex-start
}.justify-center {justify-content: center
}.justify-between {justify-content: space-between
}.gap-2 {gap: 0.5rem
}.rounded {border-radius: 0.25rem
}.rounded-md {border-radius: 0.375rem
}.border {border-width: 1px
}.border-0 {border-width: 0px
}.border-solid {border-style: solid
}.border-none {border-style: none
}.border-border-tertiary {--tw-border-opacity: 1;border-color: rgb(216 223 233 / var(--tw-border-opacity))
}.border-button-disabled {--tw-border-opacity: 1;border-color: rgb(229 231 235 / var(--tw-border-opacity))
}.border-nps-button-background {--tw-border-opacity: 1;border-color: rgb(34 113 177 / var(--tw-border-opacity))
}.border-transparent {border-color: transparent
}.border-white {--tw-border-opacity: 1;border-color: rgb(255 255 255 / var(--tw-border-opacity))
}.border-zip-body-text {--tw-border-opacity: 1;border-color: rgb(var(--zip-body-text) / var(--tw-border-opacity))
}.bg-nps-button-background {--tw-bg-opacity: 1;background-color: rgb(34 113 177 / var(--tw-bg-opacity))
}.bg-transparent {background-color: transparent
}.bg-white {--tw-bg-opacity: 1;background-color: rgb(255 255 255 / var(--tw-bg-opacity))
}.p-4 {padding: 1rem
}.px-4 {padding-left: 1rem;padding-right: 1rem
}.px-5 {padding-left: 1.25rem;padding-right: 1.25rem
}.px-6 {padding-left: 1.5rem;padding-right: 1.5rem
}.py-1\.5 {padding-top: 0.375rem;padding-bottom: 0.375rem
}.py-2 {padding-top: 0.5rem;padding-bottom: 0.5rem
}.py-3 {padding-top: 0.75rem;padding-bottom: 0.75rem
}.pl-0 {padding-left: 0px
}.pl-3 {padding-left: 0.75rem
}.pl-4 {padding-left: 1rem
}.pl-5 {padding-left: 1.25rem
}.pl-6 {padding-left: 1.5rem
}.pr-3 {padding-right: 0.75rem
}.pr-4 {padding-right: 1rem
}.pr-5 {padding-right: 1.25rem
}.pr-6 {padding-right: 1.5rem
}.text-base {font-size: 1rem;line-height: 1.5rem
}.text-lg {font-size: 1.125rem;line-height: 1.75rem
}.text-sm {font-size: 0.875rem;line-height: 1.25rem
}.text-xs {font-size: 0.75rem;line-height: 1rem
}.font-bold {font-weight: 700
}.font-medium {font-weight: 500
}.font-normal {font-weight: 400
}.font-semibold {font-weight: 600
}.leading-5 {line-height: 1.25rem
}.leading-6 {line-height: 1.5rem
}.leading-7 {line-height: 1.75rem
}.text-border-secondary {--tw-text-opacity: 1;color: rgb(107 114 128 / var(--tw-text-opacity))
}.text-nps-button-background {--tw-text-opacity: 1;color: rgb(34 113 177 / var(--tw-text-opacity))
}.text-secondary-text {--tw-text-opacity: 1;color: rgb(156 163 175 / var(--tw-text-opacity))
}.text-white {--tw-text-opacity: 1;color: rgb(255 255 255 / var(--tw-text-opacity))
}.text-zip-app-heading {--tw-text-opacity: 1;color: rgb(var(--zip-app-heading) / var(--tw-text-opacity))
}.text-zip-app-inactive-icon {--tw-text-opacity: 1;color: rgb(var(--zip-app-inactive-icon) / var(--tw-text-opacity))
}.text-zip-body-text {--tw-text-opacity: 1;color: rgb(var(--zip-body-text) / var(--tw-text-opacity))
}.underline {text-decoration-line: underline
}.no-underline {text-decoration-line: none
}.opacity-25 {opacity: 0.25
}.opacity-50 {opacity: 0.5
}.opacity-70 {opacity: 0.7
}.opacity-75 {opacity: 0.75
}.shadow-lg {--tw-shadow: 0 10px 15px -3px rgb(0 0 0 / 0.1), 0 4px 6px -4px rgb(0 0 0 / 0.1);--tw-shadow-colored: 0 10px 15px -3px var(--tw-shadow-color), 0 4px 6px -4px var(--tw-shadow-color);box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.shadow-sm {--tw-shadow: 0px 1px 2px 0px rgba(0, 0, 0, 0.05);--tw-shadow-colored: 0px 1px 2px 0px var(--tw-shadow-color);box-shadow: var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)
}.transition {transition-property: color, background-color, border-color, text-decoration-color, fill, stroke, opacity, box-shadow, transform, filter, -webkit-backdrop-filter;transition-property: color, background-color, border-color, text-decoration-color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter;transition-property: color, background-color, border-color, text-decoration-color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter, -webkit-backdrop-filter;transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1);transition-duration: 150ms
}.transition-colors {transition-property: color, background-color, border-color, text-decoration-color, fill, stroke;transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1);transition-duration: 150ms
}.duration-150 {transition-duration: 150ms
}.ease-in-out {transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1)
}.nps-survey-root {font-size: 1rem;line-height: 1.5rem
}.nps-survey-root * {box-sizing: border-box;font-family: Figtree, sans-serif
}.hover\:cursor-pointer:hover {cursor: pointer
}.hover\:bg-gray-50:hover {--tw-bg-opacity: 1;background-color: rgb(249 250 251 / var(--tw-bg-opacity))
}.focus\:z-10:focus {z-index: 10
}.focus\:ring-1:focus {--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow: var(--tw-ring-offset-shadow), var(--tw-ring-shadow), var(--tw-shadow, 0 0 #0000)
}.focus\:ring-nps-button-background:focus {--tw-ring-opacity: 1;--tw-ring-color: rgb(34 113 177 / var(--tw-ring-opacity))
}.focus-visible\:outline:focus-visible {outline-style: solid
}.focus-visible\:outline-2:focus-visible {outline-width: 2px
}.focus-visible\:outline-offset-2:focus-visible {outline-offset: 2px
}@media (min-width: 640px) {.sm\:rounded-lg {border-radius: 0.5rem
    }.sm\:p-5 {padding: 1.25rem
    }.sm\:text-sm {font-size: 0.875rem;line-height: 1.25rem
    }.sm\:leading-6 {line-height: 1.5rem
    }
}
