/* Override What's New styles for Starter Templates */
.whats-new-rss-flyout {
	font-family: "Figtree", sans-serif !important;

	&.closed {
		visibility: hidden;
	}

	.whats-new-rss-flyout-contents {
		.whats-new-rss-falyout-inner-content {
			.whats-new-rss-flyout-inner-content-item {
				padding: 40px 24px !important;
			}
		}
	}
}

.whats-new-rss-notification-badge {
	top: -12px !important;
	right: -8px !important;
}
